#[non_exhaustive]pub struct DiskImageDefaults {
pub source_image: String,
/* private fields */
}Expand description
Contains details about the image source used to create the disk.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source_image: StringRequired. The Image resource used when creating the disk.
Implementations
Sourceimpl DiskImageDefaults
impl DiskImageDefaults
Sourcepub fn set_source_image<T: Into<String>>(self, v: T) -> Self
pub fn set_source_image<T: Into<String>>(self, v: T) -> Self
Sets the value of source_image.
Example
ⓘ
let x = DiskImageDefaults::new().set_source_image("example");Trait Implementations
Sourceimpl Clone for DiskImageDefaults
impl Clone for DiskImageDefaults
Sourcefn clone(&self) -> DiskImageDefaults
fn clone(&self) -> DiskImageDefaults
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DiskImageDefaults
impl Debug for DiskImageDefaults
Sourceimpl Default for DiskImageDefaults
impl Default for DiskImageDefaults
Sourcefn default() -> DiskImageDefaults
fn default() -> DiskImageDefaults
Returns the “default value” for a type. Read more
Sourceimpl Message for DiskImageDefaults
impl Message for DiskImageDefaults
Sourceimpl PartialEq for DiskImageDefaults
impl PartialEq for DiskImageDefaults
Sourcefn eq(&self, other: &DiskImageDefaults) -> bool
fn eq(&self, other: &DiskImageDefaults) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DiskImageDefaults