#[non_exhaustive]pub enum OsCapability {
Unspecified,
NvmeStorageAccess,
GvnicNetworkInterface,
IdpfNetworkInterface,
UnknownValue(UnknownValue),
}Expand description
VM operating system (OS) capabilities needed for determining compatibility with Compute Engine features supported by the migration.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
This is for API compatibility only and is not in use.
NvmeStorageAccess
NVMe driver installed and the VM can use NVMe PD or local SSD.
GvnicNetworkInterface
gVNIC virtual NIC driver supported.
IdpfNetworkInterface
IDPF virtual NIC driver supported.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using OsCapability::value or OsCapability::name.
Implementations