#[non_exhaustive]pub enum TargetDefaults {
DiskImageTargetDefaults(Box<DiskImageTargetDetails>),
MachineImageTargetDefaults(Box<MachineImageTargetDetails>),
}Expand description
The configuration of the resources that will be created in GCP as a result of the ImageImport.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DiskImageTargetDefaults(Box<DiskImageTargetDetails>)
Immutable. Target details for importing a disk image, will be used by ImageImportJob.
MachineImageTargetDefaults(Box<MachineImageTargetDetails>)
Immutable. Target details for importing a machine image, will be used by ImageImportJob.