#[non_exhaustive]pub enum TargetVmDefaults {
ComputeEngineTargetDefaults(Box<ComputeEngineTargetDefaults>),
ComputeEngineDisksTargetDefaults(Box<ComputeEngineDisksTargetDefaults>),
}Expand description
The default configuration of the target VM that will be created in Google Cloud as a result of the migration.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ComputeEngineTargetDefaults(Box<ComputeEngineTargetDefaults>)
Details of the target VM in Compute Engine.
ComputeEngineDisksTargetDefaults(Box<ComputeEngineDisksTargetDefaults>)
Details of the target Persistent Disks in Compute Engine.