#[non_exhaustive]pub enum State {
Unspecified,
Running,
Paused,
Failed,
Succeeded,
UnknownValue(UnknownValue),
}Expand description
Possible states of a replication cycle.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
The state is unknown. This is used for API compatibility only and is not used by the system.
Running
The replication cycle is running.
Paused
The replication cycle is paused.
Failed
The replication cycle finished with errors.
Succeeded
The replication cycle finished successfully.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using State::value or State::name.
Implementations