#[non_exhaustive]pub enum Operator {
Unspecified,
In,
NotIn,
UnknownValue(UnknownValue),
}Expand description
Possible types of node selection operators. Valid operators are IN for affinity and NOT_IN for anti-affinity.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
An unknown, unexpected behavior.
In
The node resource group should be in these resources affinity.
NotIn
The node resource group should not be in these resources affinity.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using Operator::value or Operator::name.
Implementations