#[non_exhaustive]pub struct AdaptationModifier {
pub modifier: String,
pub value: String,
/* private fields */
}Expand description
AdaptationModifier a modifier to be used for configuration of the OS adaptation process.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.modifier: StringOptional. The modifier name.
value: StringOptional. The value of the modifier. The actual value depends on the modifier and can also be empty.
Implementations
Sourceimpl AdaptationModifier
impl AdaptationModifier
Sourcepub fn set_modifier<T: Into<String>>(self, v: T) -> Self
pub fn set_modifier<T: Into<String>>(self, v: T) -> Self