#[non_exhaustive]pub struct AddGroupMigrationRequest {
pub group: String,
pub migrating_vm: String,
/* private fields */
}Expand description
Request message for ‘AddGroupMigration’ request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.group: StringRequired. The full path name of the Group to add to.
migrating_vm: StringThe full path name of the MigratingVm to add.
Implementations
Sourceimpl AddGroupMigrationRequest
impl AddGroupMigrationRequest
Sourcepub fn set_migrating_vm<T: Into<String>>(self, v: T) -> Self
pub fn set_migrating_vm<T: Into<String>>(self, v: T) -> Self
Sets the value of migrating_vm.
Example
ⓘ
let x = AddGroupMigrationRequest::new().set_migrating_vm(format!("projects/{project_id}/locations/{location_id}/sources/{source_id}/migratingVms/{migrating_vm_id}"));Trait Implementations
Sourceimpl Clone for AddGroupMigrationRequest
impl Clone for AddGroupMigrationRequest
Sourcefn clone(&self) -> AddGroupMigrationRequest
fn clone(&self) -> AddGroupMigrationRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AddGroupMigrationRequest
impl Debug for AddGroupMigrationRequest
Sourceimpl Default for AddGroupMigrationRequest
impl Default for AddGroupMigrationRequest
Sourcefn default() -> AddGroupMigrationRequest
fn default() -> AddGroupMigrationRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for AddGroupMigrationRequest
impl Message for AddGroupMigrationRequest
Sourceimpl PartialEq for AddGroupMigrationRequest
impl PartialEq for AddGroupMigrationRequest
Sourcefn eq(&self, other: &AddGroupMigrationRequest) -> bool
fn eq(&self, other: &AddGroupMigrationRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AddGroupMigrationRequest