#[non_exhaustive]pub struct AvailableUpdates {
pub new_deployable_appliance: Option<ApplianceVersion>,
pub in_place_update: Option<ApplianceVersion>,
/* private fields */
}Expand description
Holds information about the available versions for upgrade.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.new_deployable_appliance: Option<ApplianceVersion>The newest deployable version of the appliance. The current appliance can’t be updated into this version, and the owner must manually deploy this OVA to a new appliance.
in_place_update: Option<ApplianceVersion>The latest version for in place update. The current appliance can be updated to this version using the API or m4c CLI.
Implementations
Sourceimpl AvailableUpdates
impl AvailableUpdates
Sourcepub fn set_new_deployable_appliance<T>(self, v: T) -> Selfwhere
T: Into<ApplianceVersion>,
pub fn set_new_deployable_appliance<T>(self, v: T) -> Selfwhere
T: Into<ApplianceVersion>,
Sets the value of new_deployable_appliance.
Example
ⓘ
use google_cloud_vmmigration_v1::model::ApplianceVersion;
let x = AvailableUpdates::new().set_new_deployable_appliance(ApplianceVersion::default()/* use setters */);Sourcepub fn set_or_clear_new_deployable_appliance<T>(self, v: Option<T>) -> Selfwhere
T: Into<ApplianceVersion>,
pub fn set_or_clear_new_deployable_appliance<T>(self, v: Option<T>) -> Selfwhere
T: Into<ApplianceVersion>,
Sets or clears the value of new_deployable_appliance.
Example
ⓘ
use google_cloud_vmmigration_v1::model::ApplianceVersion;
let x = AvailableUpdates::new().set_or_clear_new_deployable_appliance(Some(ApplianceVersion::default()/* use setters */));
let x = AvailableUpdates::new().set_or_clear_new_deployable_appliance(None::<ApplianceVersion>);Sourcepub fn set_in_place_update<T>(self, v: T) -> Selfwhere
T: Into<ApplianceVersion>,
pub fn set_in_place_update<T>(self, v: T) -> Selfwhere
T: Into<ApplianceVersion>,
Sets the value of in_place_update.
Example
ⓘ
use google_cloud_vmmigration_v1::model::ApplianceVersion;
let x = AvailableUpdates::new().set_in_place_update(ApplianceVersion::default()/* use setters */);Sourcepub fn set_or_clear_in_place_update<T>(self, v: Option<T>) -> Selfwhere
T: Into<ApplianceVersion>,
pub fn set_or_clear_in_place_update<T>(self, v: Option<T>) -> Selfwhere
T: Into<ApplianceVersion>,
Sets or clears the value of in_place_update.
Example
ⓘ
use google_cloud_vmmigration_v1::model::ApplianceVersion;
let x = AvailableUpdates::new().set_or_clear_in_place_update(Some(ApplianceVersion::default()/* use setters */));
let x = AvailableUpdates::new().set_or_clear_in_place_update(None::<ApplianceVersion>);Trait Implementations
Sourceimpl Clone for AvailableUpdates
impl Clone for AvailableUpdates
Sourcefn clone(&self) -> AvailableUpdates
fn clone(&self) -> AvailableUpdates
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AvailableUpdates
impl Debug for AvailableUpdates
Sourceimpl Default for AvailableUpdates
impl Default for AvailableUpdates
Sourcefn default() -> AvailableUpdates
fn default() -> AvailableUpdates
Returns the “default value” for a type. Read more
Sourceimpl Message for AvailableUpdates
impl Message for AvailableUpdates
Sourceimpl PartialEq for AvailableUpdates
impl PartialEq for AvailableUpdates
Sourcefn eq(&self, other: &AvailableUpdates) -> bool
fn eq(&self, other: &AvailableUpdates) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AvailableUpdates