AzureSourceDetails

Struct AzureSourceDetails 

#[non_exhaustive]
pub struct AzureSourceDetails { pub subscription_id: String, pub azure_location: String, pub state: State, pub error: Option<Status>, pub migration_resources_user_tags: HashMap<String, String>, pub resource_group_id: String, pub credentials_type: Option<CredentialsType>, /* private fields */ }
AzureSourceDetails message describes a specific source details for the Azure source type.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
subscription_id: String

Immutable. Azure subscription ID.

azure_location: String

Immutable. The Azure location (region) that the source VMs will be migrated from.

state: State

Output only. State of the source as determined by the health check.

error: Option<Status>

Output only. Provides details on the state of the Source in case of an error.

migration_resources_user_tags: HashMap<String, String>

User specified tags to add to every M2VM generated resource in Azure. These tags will be set in addition to the default tags that are set as part of the migration process. The tags must not begin with the reserved prefix m4ce or m2vm.

resource_group_id: String

Output only. The ID of the Azure resource group that contains all resources related to the migration process of this source.

credentials_type: Option<CredentialsType>

Implementations

Source

impl AzureSourceDetails

pub fn new() -> Self

Creates a new default instance.

pub fn set_subscription_id<T: Into<String>>(self, v: T) -> Self

Sets the value of subscription_id.

Example
let x = AzureSourceDetails::new().set_subscription_id("example");
pub fn set_azure_location<T: Into<String>>(self, v: T) -> Self

Sets the value of azure_location.

Example
let x = AzureSourceDetails::new().set_azure_location("example");
pub fn set_state<T: Into<State>>(self, v: T) -> Self

Sets the value of state.

Example
use google_cloud_vmmigration_v1::model::azure_source_details::State;
let x0 = AzureSourceDetails::new().set_state(State::Pending);
let x1 = AzureSourceDetails::new().set_state(State::Failed);
let x2 = AzureSourceDetails::new().set_state(State::Active);
pub fn set_error<T>(self, v: T) -> Self
where T: Into<Status>,

Sets the value of error.

Example
use google_cloud_rpc::model::Status;
let x = AzureSourceDetails::new().set_error(Status::default()/* use setters */);
pub fn set_or_clear_error<T>(self, v: Option<T>) -> Self
where T: Into<Status>,

Sets or clears the value of error.

Example
use google_cloud_rpc::model::Status;
let x = AzureSourceDetails::new().set_or_clear_error(Some(Status::default()/* use setters */));
let x = AzureSourceDetails::new().set_or_clear_error(None::<Status>);
pub fn set_migration_resources_user_tags<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of migration_resources_user_tags.

Example
let x = AzureSourceDetails::new().set_migration_resources_user_tags([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_resource_group_id<T: Into<String>>(self, v: T) -> Self

Sets the value of resource_group_id.

Example
let x = AzureSourceDetails::new().set_resource_group_id("example");
pub fn set_credentials_type<T: Into<Option<CredentialsType>>>( self, v: T, ) -> Self

Sets the value of credentials_type.

Note that all the setters affecting credentials_type are mutually exclusive.

Example
use google_cloud_vmmigration_v1::model::azure_source_details::ClientSecretCredentials;
let x = AzureSourceDetails::new().set_credentials_type(Some(
    google_cloud_vmmigration_v1::model::azure_source_details::CredentialsType::ClientSecretCreds(ClientSecretCredentials::default().into())));
pub fn client_secret_creds(&self) -> Option<&Box<ClientSecretCredentials>>

The value of credentials_type if it holds a ClientSecretCreds, None if the field is not set or holds a different branch.

pub fn set_client_secret_creds<T: Into<Box<ClientSecretCredentials>>>( self, v: T, ) -> Self

Sets the value of credentials_type to hold a ClientSecretCreds.

Note that all the setters affecting credentials_type are mutually exclusive.

Example
use google_cloud_vmmigration_v1::model::azure_source_details::ClientSecretCredentials;
let x = AzureSourceDetails::new().set_client_secret_creds(ClientSecretCredentials::default()/* use setters */);
assert!(x.client_secret_creds().is_some());