#[non_exhaustive]pub struct CloneStep {
pub start_time: Option<Timestamp>,
pub end_time: Option<Timestamp>,
pub step: Option<Step>,
/* private fields */
}Expand description
CloneStep holds information about the clone step progress.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.start_time: Option<Timestamp>The time the step has started.
end_time: Option<Timestamp>The time the step has ended.
step: Option<Step>Implementations
Sourceimpl CloneStep
impl CloneStep
Sourcepub fn set_start_time<T>(self, v: T) -> Self
pub fn set_start_time<T>(self, v: T) -> Self
Sets the value of start_time.
Example
use wkt::Timestamp;
let x = CloneStep::new().set_start_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of start_time.
Example
use wkt::Timestamp;
let x = CloneStep::new().set_or_clear_start_time(Some(Timestamp::default()/* use setters */));
let x = CloneStep::new().set_or_clear_start_time(None::<Timestamp>);Sourcepub fn set_end_time<T>(self, v: T) -> Self
pub fn set_end_time<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
Sourcepub fn adapting_os(&self) -> Option<&Box<AdaptingOSStep>>
pub fn adapting_os(&self) -> Option<&Box<AdaptingOSStep>>
The value of step
if it holds a AdaptingOs, None if the field is not set or
holds a different branch.
Sourcepub fn set_adapting_os<T: Into<Box<AdaptingOSStep>>>(self, v: T) -> Self
pub fn set_adapting_os<T: Into<Box<AdaptingOSStep>>>(self, v: T) -> Self
Sets the value of step
to hold a AdaptingOs.
Note that all the setters affecting step are
mutually exclusive.
Example
use google_cloud_vmmigration_v1::model::AdaptingOSStep;
let x = CloneStep::new().set_adapting_os(AdaptingOSStep::default()/* use setters */);
assert!(x.adapting_os().is_some());
assert!(x.preparing_vm_disks().is_none());
assert!(x.instantiating_migrated_vm().is_none());Sourcepub fn preparing_vm_disks(&self) -> Option<&Box<PreparingVMDisksStep>>
pub fn preparing_vm_disks(&self) -> Option<&Box<PreparingVMDisksStep>>
The value of step
if it holds a PreparingVmDisks, None if the field is not set or
holds a different branch.
Sourcepub fn set_preparing_vm_disks<T: Into<Box<PreparingVMDisksStep>>>(
self,
v: T,
) -> Self
pub fn set_preparing_vm_disks<T: Into<Box<PreparingVMDisksStep>>>( self, v: T, ) -> Self
Sets the value of step
to hold a PreparingVmDisks.
Note that all the setters affecting step are
mutually exclusive.
Example
use google_cloud_vmmigration_v1::model::PreparingVMDisksStep;
let x = CloneStep::new().set_preparing_vm_disks(PreparingVMDisksStep::default()/* use setters */);
assert!(x.preparing_vm_disks().is_some());
assert!(x.adapting_os().is_none());
assert!(x.instantiating_migrated_vm().is_none());Sourcepub fn instantiating_migrated_vm(
&self,
) -> Option<&Box<InstantiatingMigratedVMStep>>
pub fn instantiating_migrated_vm( &self, ) -> Option<&Box<InstantiatingMigratedVMStep>>
The value of step
if it holds a InstantiatingMigratedVm, None if the field is not set or
holds a different branch.
Sourcepub fn set_instantiating_migrated_vm<T: Into<Box<InstantiatingMigratedVMStep>>>(
self,
v: T,
) -> Self
pub fn set_instantiating_migrated_vm<T: Into<Box<InstantiatingMigratedVMStep>>>( self, v: T, ) -> Self
Sets the value of step
to hold a InstantiatingMigratedVm.
Note that all the setters affecting step are
mutually exclusive.
Example
use google_cloud_vmmigration_v1::model::InstantiatingMigratedVMStep;
let x = CloneStep::new().set_instantiating_migrated_vm(InstantiatingMigratedVMStep::default()/* use setters */);
assert!(x.instantiating_migrated_vm().is_some());
assert!(x.adapting_os().is_none());
assert!(x.preparing_vm_disks().is_none());