#[non_exhaustive]pub struct ComputeEngineDisk {
pub disk_id: String,
pub zone: String,
pub replica_zones: Vec<String>,
pub disk_type: ComputeEngineDiskType,
/* private fields */
}Expand description
Compute Engine disk target details.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.disk_id: StringOptional. Target Compute Engine Disk ID. This is the resource ID segment of the Compute Engine Disk to create. In the resource name compute/v1/projects/{project}/zones/{zone}/disks/disk1 “disk1” is the resource ID for the disk.
zone: StringRequired. The Compute Engine zone in which to create the disk. Should be of the form: projects/{target-project}/locations/{zone}
replica_zones: Vec<String>Optional. Replication zones of the regional disk. Should be of the form: projects/{target-project}/locations/{replica-zone} Currently only one replica zone is supported.
disk_type: ComputeEngineDiskTypeRequired. The disk type to use.
Implementations
Sourceimpl ComputeEngineDisk
impl ComputeEngineDisk
Sourcepub fn set_disk_id<T: Into<String>>(self, v: T) -> Self
pub fn set_disk_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_replica_zones<T, V>(self, v: T) -> Self
pub fn set_replica_zones<T, V>(self, v: T) -> Self
Sets the value of replica_zones.
Example
ⓘ
let x = ComputeEngineDisk::new().set_replica_zones(["a", "b", "c"]);Sourcepub fn set_disk_type<T: Into<ComputeEngineDiskType>>(self, v: T) -> Self
pub fn set_disk_type<T: Into<ComputeEngineDiskType>>(self, v: T) -> Self
Sets the value of disk_type.
Example
ⓘ
use google_cloud_vmmigration_v1::model::ComputeEngineDiskType;
let x0 = ComputeEngineDisk::new().set_disk_type(ComputeEngineDiskType::Standard);
let x1 = ComputeEngineDisk::new().set_disk_type(ComputeEngineDiskType::Ssd);
let x2 = ComputeEngineDisk::new().set_disk_type(ComputeEngineDiskType::Balanced);Trait Implementations
Sourceimpl Clone for ComputeEngineDisk
impl Clone for ComputeEngineDisk
Sourcefn clone(&self) -> ComputeEngineDisk
fn clone(&self) -> ComputeEngineDisk
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ComputeEngineDisk
impl Debug for ComputeEngineDisk
Sourceimpl Default for ComputeEngineDisk
impl Default for ComputeEngineDisk
Sourcefn default() -> ComputeEngineDisk
fn default() -> ComputeEngineDisk
Returns the “default value” for a type. Read more
Sourceimpl Message for ComputeEngineDisk
impl Message for ComputeEngineDisk
Sourceimpl PartialEq for ComputeEngineDisk
impl PartialEq for ComputeEngineDisk
Sourcefn eq(&self, other: &ComputeEngineDisk) -> bool
fn eq(&self, other: &ComputeEngineDisk) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ComputeEngineDisk