#[non_exhaustive]pub struct ComputeEngineDisksTargetDetails {
pub disks: Vec<PersistentDisk>,
pub vm_target: Option<VmTarget>,
/* private fields */
}Expand description
ComputeEngineDisksTargetDetails is a collection of created Persistent Disks details.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.disks: Vec<PersistentDisk>The details of each created Persistent Disk.
vm_target: Option<VmTarget>Details of the VM the disks are attached to.
Implementations
Sourceimpl ComputeEngineDisksTargetDetails
impl ComputeEngineDisksTargetDetails
Sourcepub fn set_vm_target<T: Into<Option<VmTarget>>>(self, v: T) -> Self
pub fn set_vm_target<T: Into<Option<VmTarget>>>(self, v: T) -> Self
Sets the value of vm_target.
Note that all the setters affecting vm_target are mutually
exclusive.
Example
ⓘ
use google_cloud_vmmigration_v1::model::DisksMigrationDisksTargetDetails;
let x = ComputeEngineDisksTargetDetails::new().set_vm_target(Some(
google_cloud_vmmigration_v1::model::compute_engine_disks_target_details::VmTarget::DisksTargetDetails(DisksMigrationDisksTargetDetails::default().into())));Sourcepub fn disks_target_details(
&self,
) -> Option<&Box<DisksMigrationDisksTargetDetails>>
pub fn disks_target_details( &self, ) -> Option<&Box<DisksMigrationDisksTargetDetails>>
The value of vm_target
if it holds a DisksTargetDetails, None if the field is not set or
holds a different branch.
Sourcepub fn set_disks_target_details<T: Into<Box<DisksMigrationDisksTargetDetails>>>(
self,
v: T,
) -> Self
pub fn set_disks_target_details<T: Into<Box<DisksMigrationDisksTargetDetails>>>( self, v: T, ) -> Self
Sets the value of vm_target
to hold a DisksTargetDetails.
Note that all the setters affecting vm_target are
mutually exclusive.
Example
ⓘ
use google_cloud_vmmigration_v1::model::DisksMigrationDisksTargetDetails;
let x = ComputeEngineDisksTargetDetails::new().set_disks_target_details(DisksMigrationDisksTargetDetails::default()/* use setters */);
assert!(x.disks_target_details().is_some());
assert!(x.vm_target_details().is_none());Sourcepub fn vm_target_details(&self) -> Option<&Box<DisksMigrationVmTargetDetails>>
pub fn vm_target_details(&self) -> Option<&Box<DisksMigrationVmTargetDetails>>
The value of vm_target
if it holds a VmTargetDetails, None if the field is not set or
holds a different branch.
Sourcepub fn set_vm_target_details<T: Into<Box<DisksMigrationVmTargetDetails>>>(
self,
v: T,
) -> Self
pub fn set_vm_target_details<T: Into<Box<DisksMigrationVmTargetDetails>>>( self, v: T, ) -> Self
Sets the value of vm_target
to hold a VmTargetDetails.
Note that all the setters affecting vm_target are
mutually exclusive.
Example
ⓘ
use google_cloud_vmmigration_v1::model::DisksMigrationVmTargetDetails;
let x = ComputeEngineDisksTargetDetails::new().set_vm_target_details(DisksMigrationVmTargetDetails::default()/* use setters */);
assert!(x.vm_target_details().is_some());
assert!(x.disks_target_details().is_none());Trait Implementations
Sourceimpl Clone for ComputeEngineDisksTargetDetails
impl Clone for ComputeEngineDisksTargetDetails
Sourcefn clone(&self) -> ComputeEngineDisksTargetDetails
fn clone(&self) -> ComputeEngineDisksTargetDetails
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ComputeEngineDisksTargetDetails
impl Default for ComputeEngineDisksTargetDetails
Sourcefn default() -> ComputeEngineDisksTargetDetails
fn default() -> ComputeEngineDisksTargetDetails
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ComputeEngineDisksTargetDetails
impl PartialEq for ComputeEngineDisksTargetDetails
Sourcefn eq(&self, other: &ComputeEngineDisksTargetDetails) -> bool
fn eq(&self, other: &ComputeEngineDisksTargetDetails) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ComputeEngineDisksTargetDetails