#[non_exhaustive]pub struct CreateCloneJobRequest {
pub parent: String,
pub clone_job_id: String,
pub clone_job: Option<CloneJob>,
pub request_id: String,
/* private fields */
}Expand description
Request message for ‘CreateCloneJob’ request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The Clone’s parent.
clone_job_id: StringRequired. The clone job identifier.
clone_job: Option<CloneJob>Required. The clone request body.
request_id: StringA request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateCloneJobRequest
impl CreateCloneJobRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_clone_job_id<T: Into<String>>(self, v: T) -> Self
pub fn set_clone_job_id<T: Into<String>>(self, v: T) -> Self
Sets the value of clone_job_id.
Example
let x = CreateCloneJobRequest::new().set_clone_job_id("example");Sourcepub fn set_clone_job<T>(self, v: T) -> Self
pub fn set_clone_job<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_clone_job<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_clone_job<T>(self, v: Option<T>) -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateCloneJobRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateCloneJobRequest
impl Clone for CreateCloneJobRequest
Sourcefn clone(&self) -> CreateCloneJobRequest
fn clone(&self) -> CreateCloneJobRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateCloneJobRequest
impl Debug for CreateCloneJobRequest
Sourceimpl Default for CreateCloneJobRequest
impl Default for CreateCloneJobRequest
Sourcefn default() -> CreateCloneJobRequest
fn default() -> CreateCloneJobRequest
Sourceimpl Message for CreateCloneJobRequest
impl Message for CreateCloneJobRequest
Sourceimpl PartialEq for CreateCloneJobRequest
impl PartialEq for CreateCloneJobRequest
Sourcefn eq(&self, other: &CreateCloneJobRequest) -> bool
fn eq(&self, other: &CreateCloneJobRequest) -> bool
self and other values to be equal, and is used by ==.