#[non_exhaustive]pub struct CreateCutoverJobRequest {
pub parent: String,
pub cutover_job_id: String,
pub cutover_job: Option<CutoverJob>,
pub request_id: String,
/* private fields */
}Expand description
Request message for ‘CreateCutoverJob’ request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The Cutover’s parent.
cutover_job_id: StringRequired. The cutover job identifier.
cutover_job: Option<CutoverJob>Required. The cutover request body.
request_id: StringA request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateCutoverJobRequest
impl CreateCutoverJobRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_cutover_job_id<T: Into<String>>(self, v: T) -> Self
pub fn set_cutover_job_id<T: Into<String>>(self, v: T) -> Self
Sets the value of cutover_job_id.
Example
let x = CreateCutoverJobRequest::new().set_cutover_job_id("example");Sourcepub fn set_cutover_job<T>(self, v: T) -> Selfwhere
T: Into<CutoverJob>,
pub fn set_cutover_job<T>(self, v: T) -> Selfwhere
T: Into<CutoverJob>,
Sets the value of cutover_job.
Example
use google_cloud_vmmigration_v1::model::CutoverJob;
let x = CreateCutoverJobRequest::new().set_cutover_job(CutoverJob::default()/* use setters */);Sourcepub fn set_or_clear_cutover_job<T>(self, v: Option<T>) -> Selfwhere
T: Into<CutoverJob>,
pub fn set_or_clear_cutover_job<T>(self, v: Option<T>) -> Selfwhere
T: Into<CutoverJob>,
Sets or clears the value of cutover_job.
Example
use google_cloud_vmmigration_v1::model::CutoverJob;
let x = CreateCutoverJobRequest::new().set_or_clear_cutover_job(Some(CutoverJob::default()/* use setters */));
let x = CreateCutoverJobRequest::new().set_or_clear_cutover_job(None::<CutoverJob>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateCutoverJobRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateCutoverJobRequest
impl Clone for CreateCutoverJobRequest
Sourcefn clone(&self) -> CreateCutoverJobRequest
fn clone(&self) -> CreateCutoverJobRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateCutoverJobRequest
impl Debug for CreateCutoverJobRequest
Sourceimpl Default for CreateCutoverJobRequest
impl Default for CreateCutoverJobRequest
Sourcefn default() -> CreateCutoverJobRequest
fn default() -> CreateCutoverJobRequest
Sourceimpl Message for CreateCutoverJobRequest
impl Message for CreateCutoverJobRequest
Sourceimpl PartialEq for CreateCutoverJobRequest
impl PartialEq for CreateCutoverJobRequest
Sourcefn eq(&self, other: &CreateCutoverJobRequest) -> bool
fn eq(&self, other: &CreateCutoverJobRequest) -> bool
self and other values to be equal, and is used by ==.