#[non_exhaustive]pub struct CreateGroupRequest {
pub parent: String,
pub group_id: String,
pub group: Option<Group>,
pub request_id: String,
/* private fields */
}Expand description
Request message for ‘CreateGroup’ request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The Group’s parent.
group_id: StringRequired. The group identifier.
group: Option<Group>Required. The create request body.
request_id: StringA request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateGroupRequest
impl CreateGroupRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_group_id<T: Into<String>>(self, v: T) -> Self
pub fn set_group_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_or_clear_group<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_group<T>(self, v: Option<T>) -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateGroupRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateGroupRequest
impl Clone for CreateGroupRequest
Sourcefn clone(&self) -> CreateGroupRequest
fn clone(&self) -> CreateGroupRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateGroupRequest
impl Debug for CreateGroupRequest
Sourceimpl Default for CreateGroupRequest
impl Default for CreateGroupRequest
Sourcefn default() -> CreateGroupRequest
fn default() -> CreateGroupRequest
Sourceimpl Message for CreateGroupRequest
impl Message for CreateGroupRequest
Sourceimpl PartialEq for CreateGroupRequest
impl PartialEq for CreateGroupRequest
Sourcefn eq(&self, other: &CreateGroupRequest) -> bool
fn eq(&self, other: &CreateGroupRequest) -> bool
self and other values to be equal, and is used by ==.