#[non_exhaustive]pub struct CreateImageImportRequest {
pub parent: String,
pub image_import_id: String,
pub image_import: Option<ImageImport>,
pub request_id: String,
/* private fields */
}Expand description
Request message for ‘CreateImageImport’ request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The ImageImport’s parent.
image_import_id: StringRequired. The image import identifier. This value maximum length is 63 characters, and valid characters are /[a-z][0-9]-/. It must start with an english letter and must not end with a hyphen.
image_import: Option<ImageImport>Required. The create request body.
request_id: StringOptional. A request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateImageImportRequest
impl CreateImageImportRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_image_import_id<T: Into<String>>(self, v: T) -> Self
pub fn set_image_import_id<T: Into<String>>(self, v: T) -> Self
Sets the value of image_import_id.
Example
let x = CreateImageImportRequest::new().set_image_import_id("example");Sourcepub fn set_image_import<T>(self, v: T) -> Selfwhere
T: Into<ImageImport>,
pub fn set_image_import<T>(self, v: T) -> Selfwhere
T: Into<ImageImport>,
Sets the value of image_import.
Example
use google_cloud_vmmigration_v1::model::ImageImport;
let x = CreateImageImportRequest::new().set_image_import(ImageImport::default()/* use setters */);Sourcepub fn set_or_clear_image_import<T>(self, v: Option<T>) -> Selfwhere
T: Into<ImageImport>,
pub fn set_or_clear_image_import<T>(self, v: Option<T>) -> Selfwhere
T: Into<ImageImport>,
Sets or clears the value of image_import.
Example
use google_cloud_vmmigration_v1::model::ImageImport;
let x = CreateImageImportRequest::new().set_or_clear_image_import(Some(ImageImport::default()/* use setters */));
let x = CreateImageImportRequest::new().set_or_clear_image_import(None::<ImageImport>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateImageImportRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateImageImportRequest
impl Clone for CreateImageImportRequest
Sourcefn clone(&self) -> CreateImageImportRequest
fn clone(&self) -> CreateImageImportRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateImageImportRequest
impl Debug for CreateImageImportRequest
Sourceimpl Default for CreateImageImportRequest
impl Default for CreateImageImportRequest
Sourcefn default() -> CreateImageImportRequest
fn default() -> CreateImageImportRequest
Sourceimpl Message for CreateImageImportRequest
impl Message for CreateImageImportRequest
Sourceimpl PartialEq for CreateImageImportRequest
impl PartialEq for CreateImageImportRequest
Sourcefn eq(&self, other: &CreateImageImportRequest) -> bool
fn eq(&self, other: &CreateImageImportRequest) -> bool
self and other values to be equal, and is used by ==.