#[non_exhaustive]pub struct CreateMigratingVmRequest {
pub parent: String,
pub migrating_vm_id: String,
pub migrating_vm: Option<MigratingVm>,
pub request_id: String,
/* private fields */
}Expand description
Request message for ‘CreateMigratingVm’ request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The MigratingVm’s parent.
migrating_vm_id: StringRequired. The migratingVm identifier.
migrating_vm: Option<MigratingVm>Required. The create request body.
request_id: StringA request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateMigratingVmRequest
impl CreateMigratingVmRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_migrating_vm_id<T: Into<String>>(self, v: T) -> Self
pub fn set_migrating_vm_id<T: Into<String>>(self, v: T) -> Self
Sets the value of migrating_vm_id.
Example
let x = CreateMigratingVmRequest::new().set_migrating_vm_id("example");Sourcepub fn set_migrating_vm<T>(self, v: T) -> Selfwhere
T: Into<MigratingVm>,
pub fn set_migrating_vm<T>(self, v: T) -> Selfwhere
T: Into<MigratingVm>,
Sets the value of migrating_vm.
Example
use google_cloud_vmmigration_v1::model::MigratingVm;
let x = CreateMigratingVmRequest::new().set_migrating_vm(MigratingVm::default()/* use setters */);Sourcepub fn set_or_clear_migrating_vm<T>(self, v: Option<T>) -> Selfwhere
T: Into<MigratingVm>,
pub fn set_or_clear_migrating_vm<T>(self, v: Option<T>) -> Selfwhere
T: Into<MigratingVm>,
Sets or clears the value of migrating_vm.
Example
use google_cloud_vmmigration_v1::model::MigratingVm;
let x = CreateMigratingVmRequest::new().set_or_clear_migrating_vm(Some(MigratingVm::default()/* use setters */));
let x = CreateMigratingVmRequest::new().set_or_clear_migrating_vm(None::<MigratingVm>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateMigratingVmRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateMigratingVmRequest
impl Clone for CreateMigratingVmRequest
Sourcefn clone(&self) -> CreateMigratingVmRequest
fn clone(&self) -> CreateMigratingVmRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateMigratingVmRequest
impl Debug for CreateMigratingVmRequest
Sourceimpl Default for CreateMigratingVmRequest
impl Default for CreateMigratingVmRequest
Sourcefn default() -> CreateMigratingVmRequest
fn default() -> CreateMigratingVmRequest
Sourceimpl Message for CreateMigratingVmRequest
impl Message for CreateMigratingVmRequest
Sourceimpl PartialEq for CreateMigratingVmRequest
impl PartialEq for CreateMigratingVmRequest
Sourcefn eq(&self, other: &CreateMigratingVmRequest) -> bool
fn eq(&self, other: &CreateMigratingVmRequest) -> bool
self and other values to be equal, and is used by ==.