#[non_exhaustive]pub struct CreateSourceRequest {
pub parent: String,
pub source_id: String,
pub source: Option<Source>,
pub request_id: String,
/* private fields */
}Expand description
Request message for ‘CreateSource’ request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The Source’s parent.
source_id: StringRequired. The source identifier.
source: Option<Source>Required. The create request body.
request_id: StringA request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateSourceRequest
impl CreateSourceRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_source_id<T: Into<String>>(self, v: T) -> Self
pub fn set_source_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_source<T>(self, v: T) -> Self
pub fn set_source<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_source<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_source<T>(self, v: Option<T>) -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateSourceRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateSourceRequest
impl Clone for CreateSourceRequest
Sourcefn clone(&self) -> CreateSourceRequest
fn clone(&self) -> CreateSourceRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateSourceRequest
impl Debug for CreateSourceRequest
Sourceimpl Default for CreateSourceRequest
impl Default for CreateSourceRequest
Sourcefn default() -> CreateSourceRequest
fn default() -> CreateSourceRequest
Sourceimpl Message for CreateSourceRequest
impl Message for CreateSourceRequest
Sourceimpl PartialEq for CreateSourceRequest
impl PartialEq for CreateSourceRequest
Sourcefn eq(&self, other: &CreateSourceRequest) -> bool
fn eq(&self, other: &CreateSourceRequest) -> bool
self and other values to be equal, and is used by ==.