#[non_exhaustive]pub struct CreateTargetProjectRequest {
pub parent: String,
pub target_project_id: String,
pub target_project: Option<TargetProject>,
pub request_id: String,
/* private fields */
}Expand description
Request message for ‘CreateTargetProject’ request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The TargetProject’s parent.
target_project_id: StringRequired. The target_project identifier.
target_project: Option<TargetProject>Required. The create request body.
request_id: StringA request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateTargetProjectRequest
impl CreateTargetProjectRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_target_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_target_project_id<T: Into<String>>(self, v: T) -> Self
Sets the value of target_project_id.
Example
let x = CreateTargetProjectRequest::new().set_target_project_id("example");Sourcepub fn set_target_project<T>(self, v: T) -> Selfwhere
T: Into<TargetProject>,
pub fn set_target_project<T>(self, v: T) -> Selfwhere
T: Into<TargetProject>,
Sets the value of target_project.
Example
use google_cloud_vmmigration_v1::model::TargetProject;
let x = CreateTargetProjectRequest::new().set_target_project(TargetProject::default()/* use setters */);Sourcepub fn set_or_clear_target_project<T>(self, v: Option<T>) -> Selfwhere
T: Into<TargetProject>,
pub fn set_or_clear_target_project<T>(self, v: Option<T>) -> Selfwhere
T: Into<TargetProject>,
Sets or clears the value of target_project.
Example
use google_cloud_vmmigration_v1::model::TargetProject;
let x = CreateTargetProjectRequest::new().set_or_clear_target_project(Some(TargetProject::default()/* use setters */));
let x = CreateTargetProjectRequest::new().set_or_clear_target_project(None::<TargetProject>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateTargetProjectRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateTargetProjectRequest
impl Clone for CreateTargetProjectRequest
Sourcefn clone(&self) -> CreateTargetProjectRequest
fn clone(&self) -> CreateTargetProjectRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateTargetProjectRequest
impl Debug for CreateTargetProjectRequest
Sourceimpl Default for CreateTargetProjectRequest
impl Default for CreateTargetProjectRequest
Sourcefn default() -> CreateTargetProjectRequest
fn default() -> CreateTargetProjectRequest
Sourceimpl Message for CreateTargetProjectRequest
impl Message for CreateTargetProjectRequest
Sourceimpl PartialEq for CreateTargetProjectRequest
impl PartialEq for CreateTargetProjectRequest
Sourcefn eq(&self, other: &CreateTargetProjectRequest) -> bool
fn eq(&self, other: &CreateTargetProjectRequest) -> bool
self and other values to be equal, and is used by ==.