#[non_exhaustive]pub struct CreateUtilizationReportRequest {
pub parent: String,
pub utilization_report: Option<UtilizationReport>,
pub utilization_report_id: String,
pub request_id: String,
/* private fields */
}Expand description
Request message for ‘CreateUtilizationReport’ request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The Utilization Report’s parent.
utilization_report: Option<UtilizationReport>Required. The report to create.
utilization_report_id: StringRequired. The ID to use for the report, which will become the final component of the reports’s resource name.
This value maximum length is 63 characters, and valid characters are /[a-z][0-9]-/. It must start with an english letter and must not end with a hyphen.
request_id: StringA request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateUtilizationReportRequest
impl CreateUtilizationReportRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_utilization_report<T>(self, v: T) -> Selfwhere
T: Into<UtilizationReport>,
pub fn set_utilization_report<T>(self, v: T) -> Selfwhere
T: Into<UtilizationReport>,
Sets the value of utilization_report.
Example
use google_cloud_vmmigration_v1::model::UtilizationReport;
let x = CreateUtilizationReportRequest::new().set_utilization_report(UtilizationReport::default()/* use setters */);Sourcepub fn set_or_clear_utilization_report<T>(self, v: Option<T>) -> Selfwhere
T: Into<UtilizationReport>,
pub fn set_or_clear_utilization_report<T>(self, v: Option<T>) -> Selfwhere
T: Into<UtilizationReport>,
Sets or clears the value of utilization_report.
Example
use google_cloud_vmmigration_v1::model::UtilizationReport;
let x = CreateUtilizationReportRequest::new().set_or_clear_utilization_report(Some(UtilizationReport::default()/* use setters */));
let x = CreateUtilizationReportRequest::new().set_or_clear_utilization_report(None::<UtilizationReport>);Sourcepub fn set_utilization_report_id<T: Into<String>>(self, v: T) -> Self
pub fn set_utilization_report_id<T: Into<String>>(self, v: T) -> Self
Sets the value of utilization_report_id.
Example
let x = CreateUtilizationReportRequest::new().set_utilization_report_id("example");Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateUtilizationReportRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateUtilizationReportRequest
impl Clone for CreateUtilizationReportRequest
Sourcefn clone(&self) -> CreateUtilizationReportRequest
fn clone(&self) -> CreateUtilizationReportRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for CreateUtilizationReportRequest
impl Default for CreateUtilizationReportRequest
Sourcefn default() -> CreateUtilizationReportRequest
fn default() -> CreateUtilizationReportRequest
Sourceimpl PartialEq for CreateUtilizationReportRequest
impl PartialEq for CreateUtilizationReportRequest
Sourcefn eq(&self, other: &CreateUtilizationReportRequest) -> bool
fn eq(&self, other: &CreateUtilizationReportRequest) -> bool
self and other values to be equal, and is used by ==.