CutoverJob

Struct CutoverJob 

#[non_exhaustive]
pub struct CutoverJob { pub create_time: Option<Timestamp>, pub end_time: Option<Timestamp>, pub name: String, pub state: State, pub state_time: Option<Timestamp>, pub progress_percent: i32, pub error: Option<Status>, pub state_message: String, pub steps: Vec<CutoverStep>, pub target_vm_details: Option<TargetVmDetails>, /* private fields */ }
CutoverJob message describes a cutover of a migrating VM. The CutoverJob is the operation of shutting down the VM, creating a snapshot and cloning the VM using the replicated snapshot.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
create_time: Option<Timestamp>

Output only. The time the cutover job was created (as an API call, not when it was actually created in the target).

end_time: Option<Timestamp>

Output only. The time the cutover job had finished.

name: String

Output only. The name of the cutover job.

state: State

Output only. State of the cutover job.

state_time: Option<Timestamp>

Output only. The time the state was last updated.

progress_percent: i32

Output only. The current progress in percentage of the cutover job.

error: Option<Status>

Output only. Provides details for the errors that led to the Cutover Job’s state.

state_message: String

Output only. A message providing possible extra details about the current state.

steps: Vec<CutoverStep>

Output only. The cutover steps list representing its progress.

target_vm_details: Option<TargetVmDetails>

Details of the VM to create as the target of this cutover job.

Implementations

Source

impl CutoverJob

pub fn new() -> Self

Creates a new default instance.

pub fn set_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of create_time.

Example
use wkt::Timestamp;
let x = CutoverJob::new().set_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of create_time.

Example
use wkt::Timestamp;
let x = CutoverJob::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = CutoverJob::new().set_or_clear_create_time(None::<Timestamp>);
pub fn set_end_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of end_time.

Example
use wkt::Timestamp;
let x = CutoverJob::new().set_end_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of end_time.

Example
use wkt::Timestamp;
let x = CutoverJob::new().set_or_clear_end_time(Some(Timestamp::default()/* use setters */));
let x = CutoverJob::new().set_or_clear_end_time(None::<Timestamp>);
pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = CutoverJob::new().set_name(format!("projects/{project_id}/locations/{location_id}/sources/{source_id}/migratingVms/{migrating_vm_id}/cutoverJobs/{cutover_job_id}"));
pub fn set_state<T: Into<State>>(self, v: T) -> Self

Sets the value of state.

Example
use google_cloud_vmmigration_v1::model::cutover_job::State;
let x0 = CutoverJob::new().set_state(State::Pending);
let x1 = CutoverJob::new().set_state(State::Failed);
let x2 = CutoverJob::new().set_state(State::Succeeded);
pub fn set_state_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of state_time.

Example
use wkt::Timestamp;
let x = CutoverJob::new().set_state_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_state_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of state_time.

Example
use wkt::Timestamp;
let x = CutoverJob::new().set_or_clear_state_time(Some(Timestamp::default()/* use setters */));
let x = CutoverJob::new().set_or_clear_state_time(None::<Timestamp>);
pub fn set_progress_percent<T: Into<i32>>(self, v: T) -> Self

Sets the value of progress_percent.

Example
let x = CutoverJob::new().set_progress_percent(42);
pub fn set_error<T>(self, v: T) -> Self
where T: Into<Status>,

Sets the value of error.

Example
use google_cloud_rpc::model::Status;
let x = CutoverJob::new().set_error(Status::default()/* use setters */);
pub fn set_or_clear_error<T>(self, v: Option<T>) -> Self
where T: Into<Status>,

Sets or clears the value of error.

Example
use google_cloud_rpc::model::Status;
let x = CutoverJob::new().set_or_clear_error(Some(Status::default()/* use setters */));
let x = CutoverJob::new().set_or_clear_error(None::<Status>);
pub fn set_state_message<T: Into<String>>(self, v: T) -> Self

Sets the value of state_message.

Example
let x = CutoverJob::new().set_state_message("example");
pub fn set_steps<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<CutoverStep>,

Sets the value of steps.

Example
use google_cloud_vmmigration_v1::model::CutoverStep;
let x = CutoverJob::new()
    .set_steps([
        CutoverStep::default()/* use setters */,
        CutoverStep::default()/* use (different) setters */,
    ]);
pub fn set_target_vm_details<T: Into<Option<TargetVmDetails>>>( self, v: T, ) -> Self

Sets the value of target_vm_details.

Note that all the setters affecting target_vm_details are mutually exclusive.

Example
use google_cloud_vmmigration_v1::model::ComputeEngineTargetDetails;
let x = CutoverJob::new().set_target_vm_details(Some(
    google_cloud_vmmigration_v1::model::cutover_job::TargetVmDetails::ComputeEngineTargetDetails(ComputeEngineTargetDetails::default().into())));
pub fn compute_engine_target_details( &self, ) -> Option<&Box<ComputeEngineTargetDetails>>

The value of target_vm_details if it holds a ComputeEngineTargetDetails, None if the field is not set or holds a different branch.

pub fn set_compute_engine_target_details<T: Into<Box<ComputeEngineTargetDetails>>>( self, v: T, ) -> Self

Sets the value of target_vm_details to hold a ComputeEngineTargetDetails.

Note that all the setters affecting target_vm_details are mutually exclusive.

Example
use google_cloud_vmmigration_v1::model::ComputeEngineTargetDetails;
let x = CutoverJob::new().set_compute_engine_target_details(ComputeEngineTargetDetails::default()/* use setters */);
assert!(x.compute_engine_target_details().is_some());
assert!(x.compute_engine_disks_target_details().is_none());
pub fn compute_engine_disks_target_details( &self, ) -> Option<&Box<ComputeEngineDisksTargetDetails>>

The value of target_vm_details if it holds a ComputeEngineDisksTargetDetails, None if the field is not set or holds a different branch.

pub fn set_compute_engine_disks_target_details<T: Into<Box<ComputeEngineDisksTargetDetails>>>( self, v: T, ) -> Self

Sets the value of target_vm_details to hold a ComputeEngineDisksTargetDetails.

Note that all the setters affecting target_vm_details are mutually exclusive.

Example
use google_cloud_vmmigration_v1::model::ComputeEngineDisksTargetDetails;
let x = CutoverJob::new().set_compute_engine_disks_target_details(ComputeEngineDisksTargetDetails::default()/* use setters */);
assert!(x.compute_engine_disks_target_details().is_some());
assert!(x.compute_engine_target_details().is_none());