#[non_exhaustive]pub struct CutoverStep {
pub start_time: Option<Timestamp>,
pub end_time: Option<Timestamp>,
pub step: Option<Step>,
/* private fields */
}Expand description
CutoverStep holds information about the cutover step progress.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.start_time: Option<Timestamp>The time the step has started.
end_time: Option<Timestamp>The time the step has ended.
step: Option<Step>Implementations
Sourceimpl CutoverStep
impl CutoverStep
Sourcepub fn set_start_time<T>(self, v: T) -> Self
pub fn set_start_time<T>(self, v: T) -> Self
Sets the value of start_time.
Example
use wkt::Timestamp;
let x = CutoverStep::new().set_start_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of start_time.
Example
use wkt::Timestamp;
let x = CutoverStep::new().set_or_clear_start_time(Some(Timestamp::default()/* use setters */));
let x = CutoverStep::new().set_or_clear_start_time(None::<Timestamp>);Sourcepub fn set_end_time<T>(self, v: T) -> Self
pub fn set_end_time<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
Sourcepub fn set_step<T: Into<Option<Step>>>(self, v: T) -> Self
pub fn set_step<T: Into<Option<Step>>>(self, v: T) -> Self
Sets the value of step.
Note that all the setters affecting step are mutually
exclusive.
Example
use google_cloud_vmmigration_v1::model::ReplicationCycle;
let x = CutoverStep::new().set_step(Some(
google_cloud_vmmigration_v1::model::cutover_step::Step::PreviousReplicationCycle(ReplicationCycle::default().into())));Sourcepub fn previous_replication_cycle(&self) -> Option<&Box<ReplicationCycle>>
pub fn previous_replication_cycle(&self) -> Option<&Box<ReplicationCycle>>
The value of step
if it holds a PreviousReplicationCycle, None if the field is not set or
holds a different branch.
Sourcepub fn set_previous_replication_cycle<T: Into<Box<ReplicationCycle>>>(
self,
v: T,
) -> Self
pub fn set_previous_replication_cycle<T: Into<Box<ReplicationCycle>>>( self, v: T, ) -> Self
Sets the value of step
to hold a PreviousReplicationCycle.
Note that all the setters affecting step are
mutually exclusive.
Example
use google_cloud_vmmigration_v1::model::ReplicationCycle;
let x = CutoverStep::new().set_previous_replication_cycle(ReplicationCycle::default()/* use setters */);
assert!(x.previous_replication_cycle().is_some());
assert!(x.shutting_down_source_vm().is_none());
assert!(x.final_sync().is_none());
assert!(x.preparing_vm_disks().is_none());
assert!(x.instantiating_migrated_vm().is_none());Sourcepub fn shutting_down_source_vm(&self) -> Option<&Box<ShuttingDownSourceVMStep>>
pub fn shutting_down_source_vm(&self) -> Option<&Box<ShuttingDownSourceVMStep>>
The value of step
if it holds a ShuttingDownSourceVm, None if the field is not set or
holds a different branch.
Sourcepub fn set_shutting_down_source_vm<T: Into<Box<ShuttingDownSourceVMStep>>>(
self,
v: T,
) -> Self
pub fn set_shutting_down_source_vm<T: Into<Box<ShuttingDownSourceVMStep>>>( self, v: T, ) -> Self
Sets the value of step
to hold a ShuttingDownSourceVm.
Note that all the setters affecting step are
mutually exclusive.
Example
use google_cloud_vmmigration_v1::model::ShuttingDownSourceVMStep;
let x = CutoverStep::new().set_shutting_down_source_vm(ShuttingDownSourceVMStep::default()/* use setters */);
assert!(x.shutting_down_source_vm().is_some());
assert!(x.previous_replication_cycle().is_none());
assert!(x.final_sync().is_none());
assert!(x.preparing_vm_disks().is_none());
assert!(x.instantiating_migrated_vm().is_none());Sourcepub fn final_sync(&self) -> Option<&Box<ReplicationCycle>>
pub fn final_sync(&self) -> Option<&Box<ReplicationCycle>>
The value of step
if it holds a FinalSync, None if the field is not set or
holds a different branch.
Sourcepub fn set_final_sync<T: Into<Box<ReplicationCycle>>>(self, v: T) -> Self
pub fn set_final_sync<T: Into<Box<ReplicationCycle>>>(self, v: T) -> Self
Sets the value of step
to hold a FinalSync.
Note that all the setters affecting step are
mutually exclusive.
Example
use google_cloud_vmmigration_v1::model::ReplicationCycle;
let x = CutoverStep::new().set_final_sync(ReplicationCycle::default()/* use setters */);
assert!(x.final_sync().is_some());
assert!(x.previous_replication_cycle().is_none());
assert!(x.shutting_down_source_vm().is_none());
assert!(x.preparing_vm_disks().is_none());
assert!(x.instantiating_migrated_vm().is_none());Sourcepub fn preparing_vm_disks(&self) -> Option<&Box<PreparingVMDisksStep>>
pub fn preparing_vm_disks(&self) -> Option<&Box<PreparingVMDisksStep>>
The value of step
if it holds a PreparingVmDisks, None if the field is not set or
holds a different branch.
Sourcepub fn set_preparing_vm_disks<T: Into<Box<PreparingVMDisksStep>>>(
self,
v: T,
) -> Self
pub fn set_preparing_vm_disks<T: Into<Box<PreparingVMDisksStep>>>( self, v: T, ) -> Self
Sets the value of step
to hold a PreparingVmDisks.
Note that all the setters affecting step are
mutually exclusive.
Example
use google_cloud_vmmigration_v1::model::PreparingVMDisksStep;
let x = CutoverStep::new().set_preparing_vm_disks(PreparingVMDisksStep::default()/* use setters */);
assert!(x.preparing_vm_disks().is_some());
assert!(x.previous_replication_cycle().is_none());
assert!(x.shutting_down_source_vm().is_none());
assert!(x.final_sync().is_none());
assert!(x.instantiating_migrated_vm().is_none());Sourcepub fn instantiating_migrated_vm(
&self,
) -> Option<&Box<InstantiatingMigratedVMStep>>
pub fn instantiating_migrated_vm( &self, ) -> Option<&Box<InstantiatingMigratedVMStep>>
The value of step
if it holds a InstantiatingMigratedVm, None if the field is not set or
holds a different branch.
Sourcepub fn set_instantiating_migrated_vm<T: Into<Box<InstantiatingMigratedVMStep>>>(
self,
v: T,
) -> Self
pub fn set_instantiating_migrated_vm<T: Into<Box<InstantiatingMigratedVMStep>>>( self, v: T, ) -> Self
Sets the value of step
to hold a InstantiatingMigratedVm.
Note that all the setters affecting step are
mutually exclusive.
Example
use google_cloud_vmmigration_v1::model::InstantiatingMigratedVMStep;
let x = CutoverStep::new().set_instantiating_migrated_vm(InstantiatingMigratedVMStep::default()/* use setters */);
assert!(x.instantiating_migrated_vm().is_some());
assert!(x.previous_replication_cycle().is_none());
assert!(x.shutting_down_source_vm().is_none());
assert!(x.final_sync().is_none());
assert!(x.preparing_vm_disks().is_none());Trait Implementations
Sourceimpl Clone for CutoverStep
impl Clone for CutoverStep
Sourcefn clone(&self) -> CutoverStep
fn clone(&self) -> CutoverStep
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CutoverStep
impl Debug for CutoverStep
Sourceimpl Default for CutoverStep
impl Default for CutoverStep
Sourcefn default() -> CutoverStep
fn default() -> CutoverStep
Sourceimpl Message for CutoverStep
impl Message for CutoverStep
Sourceimpl PartialEq for CutoverStep
impl PartialEq for CutoverStep
Sourcefn eq(&self, other: &CutoverStep) -> bool
fn eq(&self, other: &CutoverStep) -> bool
self and other values to be equal, and is used by ==.