#[non_exhaustive]pub struct CycleStep {
pub start_time: Option<Timestamp>,
pub end_time: Option<Timestamp>,
pub step: Option<Step>,
/* private fields */
}Expand description
CycleStep holds information about a step progress.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.start_time: Option<Timestamp>The time the cycle step has started.
end_time: Option<Timestamp>The time the cycle step has ended.
step: Option<Step>Implementations
Sourceimpl CycleStep
impl CycleStep
Sourcepub fn set_start_time<T>(self, v: T) -> Self
pub fn set_start_time<T>(self, v: T) -> Self
Sets the value of start_time.
Example
use wkt::Timestamp;
let x = CycleStep::new().set_start_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of start_time.
Example
use wkt::Timestamp;
let x = CycleStep::new().set_or_clear_start_time(Some(Timestamp::default()/* use setters */));
let x = CycleStep::new().set_or_clear_start_time(None::<Timestamp>);Sourcepub fn set_end_time<T>(self, v: T) -> Self
pub fn set_end_time<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
Sourcepub fn set_step<T: Into<Option<Step>>>(self, v: T) -> Self
pub fn set_step<T: Into<Option<Step>>>(self, v: T) -> Self
Sets the value of step.
Note that all the setters affecting step are mutually
exclusive.
Example
use google_cloud_vmmigration_v1::model::InitializingReplicationStep;
let x = CycleStep::new().set_step(Some(
google_cloud_vmmigration_v1::model::cycle_step::Step::InitializingReplication(InitializingReplicationStep::default().into())));Sourcepub fn initializing_replication(
&self,
) -> Option<&Box<InitializingReplicationStep>>
pub fn initializing_replication( &self, ) -> Option<&Box<InitializingReplicationStep>>
The value of step
if it holds a InitializingReplication, None if the field is not set or
holds a different branch.
Sourcepub fn set_initializing_replication<T: Into<Box<InitializingReplicationStep>>>(
self,
v: T,
) -> Self
pub fn set_initializing_replication<T: Into<Box<InitializingReplicationStep>>>( self, v: T, ) -> Self
Sets the value of step
to hold a InitializingReplication.
Note that all the setters affecting step are
mutually exclusive.
Example
use google_cloud_vmmigration_v1::model::InitializingReplicationStep;
let x = CycleStep::new().set_initializing_replication(InitializingReplicationStep::default()/* use setters */);
assert!(x.initializing_replication().is_some());
assert!(x.replicating().is_none());
assert!(x.post_processing().is_none());Sourcepub fn replicating(&self) -> Option<&Box<ReplicatingStep>>
pub fn replicating(&self) -> Option<&Box<ReplicatingStep>>
The value of step
if it holds a Replicating, None if the field is not set or
holds a different branch.
Sourcepub fn set_replicating<T: Into<Box<ReplicatingStep>>>(self, v: T) -> Self
pub fn set_replicating<T: Into<Box<ReplicatingStep>>>(self, v: T) -> Self
Sets the value of step
to hold a Replicating.
Note that all the setters affecting step are
mutually exclusive.
Example
use google_cloud_vmmigration_v1::model::ReplicatingStep;
let x = CycleStep::new().set_replicating(ReplicatingStep::default()/* use setters */);
assert!(x.replicating().is_some());
assert!(x.initializing_replication().is_none());
assert!(x.post_processing().is_none());Sourcepub fn post_processing(&self) -> Option<&Box<PostProcessingStep>>
pub fn post_processing(&self) -> Option<&Box<PostProcessingStep>>
The value of step
if it holds a PostProcessing, None if the field is not set or
holds a different branch.
Sourcepub fn set_post_processing<T: Into<Box<PostProcessingStep>>>(self, v: T) -> Self
pub fn set_post_processing<T: Into<Box<PostProcessingStep>>>(self, v: T) -> Self
Sets the value of step
to hold a PostProcessing.
Note that all the setters affecting step are
mutually exclusive.
Example
use google_cloud_vmmigration_v1::model::PostProcessingStep;
let x = CycleStep::new().set_post_processing(PostProcessingStep::default()/* use setters */);
assert!(x.post_processing().is_some());
assert!(x.initializing_replication().is_none());
assert!(x.replicating().is_none());