DataDiskImageImport

Struct DataDiskImageImport 

#[non_exhaustive]
pub struct DataDiskImageImport { pub guest_os_features: Vec<String>, /* private fields */ }
Used when the image import is not using OS adaptation process.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
guest_os_features: Vec<String>

Optional. A list of guest OS features to apply to the imported image. These features are flags that are used by Compute Engine to enable certain capabilities for virtual machine instances that are created from the image.

This field does not change the OS of the image; it only marks the image with the specified features. The user must ensure that the OS is compatible with the features.

For a list of available features, see https://cloud.google.com/compute/docs/images/create-custom#guest-os-features.

Implementations

Source

impl DataDiskImageImport

pub fn new() -> Self

Creates a new default instance.

pub fn set_guest_os_features<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of guest_os_features.

Example
let x = DataDiskImageImport::new().set_guest_os_features(["a", "b", "c"]);