DatacenterConnector

Struct DatacenterConnector 

#[non_exhaustive]
pub struct DatacenterConnector {
Show 14 fields pub create_time: Option<Timestamp>, pub update_time: Option<Timestamp>, pub name: String, pub registration_id: String, pub service_account: String, pub version: String, pub bucket: String, pub state: State, pub state_time: Option<Timestamp>, pub error: Option<Status>, pub appliance_infrastructure_version: String, pub appliance_software_version: String, pub available_versions: Option<AvailableUpdates>, pub upgrade_status: Option<UpgradeStatus>, /* private fields */
}
DatacenterConnector message describes a connector between the Source and Google Cloud, which is installed on a vmware datacenter (an OVA vm installed by the user) to connect the Datacenter to Google Cloud and support vm migration data transfer.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
create_time: Option<Timestamp>

Output only. The time the connector was created (as an API call, not when it was actually installed).

update_time: Option<Timestamp>

Output only. The last time the connector was updated with an API call.

name: String

Output only. The connector’s name.

registration_id: String

Immutable. A unique key for this connector. This key is internal to the OVA connector and is supplied with its creation during the registration process and can not be modified.

service_account: String

The service account to use in the connector when communicating with the cloud.

version: String

The version running in the DatacenterConnector. This is supplied by the OVA connector during the registration process and can not be modified.

bucket: String

Output only. The communication channel between the datacenter connector and Google Cloud.

state: State

Output only. State of the DatacenterConnector, as determined by the health checks.

state_time: Option<Timestamp>

Output only. The time the state was last set.

error: Option<Status>

Output only. Provides details on the state of the Datacenter Connector in case of an error.

appliance_infrastructure_version: String

Output only. Appliance OVA version. This is the OVA which is manually installed by the user and contains the infrastructure for the automatically updatable components on the appliance.

appliance_software_version: String

Output only. Appliance last installed update bundle version. This is the version of the automatically updatable components on the appliance.

available_versions: Option<AvailableUpdates>

Output only. The available versions for updating this appliance.

upgrade_status: Option<UpgradeStatus>

Output only. The status of the current / last upgradeAppliance operation.

Implementations

Source

impl DatacenterConnector

pub fn new() -> Self

Creates a new default instance.

pub fn set_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of create_time.

Example
use wkt::Timestamp;
let x = DatacenterConnector::new().set_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of create_time.

Example
use wkt::Timestamp;
let x = DatacenterConnector::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = DatacenterConnector::new().set_or_clear_create_time(None::<Timestamp>);
pub fn set_update_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of update_time.

Example
use wkt::Timestamp;
let x = DatacenterConnector::new().set_update_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of update_time.

Example
use wkt::Timestamp;
let x = DatacenterConnector::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = DatacenterConnector::new().set_or_clear_update_time(None::<Timestamp>);
pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = DatacenterConnector::new().set_name(format!("projects/{project_id}/locations/{location_id}/sources/{source_id}/datacenterConnectors/{datacenter_connector_id}"));
pub fn set_registration_id<T: Into<String>>(self, v: T) -> Self

Sets the value of registration_id.

Example
let x = DatacenterConnector::new().set_registration_id("example");
pub fn set_service_account<T: Into<String>>(self, v: T) -> Self

Sets the value of service_account.

Example
let x = DatacenterConnector::new().set_service_account("example");
pub fn set_version<T: Into<String>>(self, v: T) -> Self

Sets the value of version.

Example
let x = DatacenterConnector::new().set_version("example");
pub fn set_bucket<T: Into<String>>(self, v: T) -> Self

Sets the value of bucket.

Example
let x = DatacenterConnector::new().set_bucket("example");
pub fn set_state<T: Into<State>>(self, v: T) -> Self

Sets the value of state.

Example
use google_cloud_vmmigration_v1::model::datacenter_connector::State;
let x0 = DatacenterConnector::new().set_state(State::Pending);
let x1 = DatacenterConnector::new().set_state(State::Offline);
let x2 = DatacenterConnector::new().set_state(State::Failed);
pub fn set_state_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of state_time.

Example
use wkt::Timestamp;
let x = DatacenterConnector::new().set_state_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_state_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of state_time.

Example
use wkt::Timestamp;
let x = DatacenterConnector::new().set_or_clear_state_time(Some(Timestamp::default()/* use setters */));
let x = DatacenterConnector::new().set_or_clear_state_time(None::<Timestamp>);
pub fn set_error<T>(self, v: T) -> Self
where T: Into<Status>,

Sets the value of error.

Example
use google_cloud_rpc::model::Status;
let x = DatacenterConnector::new().set_error(Status::default()/* use setters */);
pub fn set_or_clear_error<T>(self, v: Option<T>) -> Self
where T: Into<Status>,

Sets or clears the value of error.

Example
use google_cloud_rpc::model::Status;
let x = DatacenterConnector::new().set_or_clear_error(Some(Status::default()/* use setters */));
let x = DatacenterConnector::new().set_or_clear_error(None::<Status>);
pub fn set_appliance_infrastructure_version<T: Into<String>>(self, v: T) -> Self

Sets the value of appliance_infrastructure_version.

Example
let x = DatacenterConnector::new().set_appliance_infrastructure_version("example");
pub fn set_appliance_software_version<T: Into<String>>(self, v: T) -> Self

Sets the value of appliance_software_version.

Example
let x = DatacenterConnector::new().set_appliance_software_version("example");
pub fn set_available_versions<T>(self, v: T) -> Self

Sets the value of available_versions.

Example
use google_cloud_vmmigration_v1::model::AvailableUpdates;
let x = DatacenterConnector::new().set_available_versions(AvailableUpdates::default()/* use setters */);
pub fn set_or_clear_available_versions<T>(self, v: Option<T>) -> Self

Sets or clears the value of available_versions.

Example
use google_cloud_vmmigration_v1::model::AvailableUpdates;
let x = DatacenterConnector::new().set_or_clear_available_versions(Some(AvailableUpdates::default()/* use setters */));
let x = DatacenterConnector::new().set_or_clear_available_versions(None::<AvailableUpdates>);
pub fn set_upgrade_status<T>(self, v: T) -> Self
where T: Into<UpgradeStatus>,

Sets the value of upgrade_status.

Example
use google_cloud_vmmigration_v1::model::UpgradeStatus;
let x = DatacenterConnector::new().set_upgrade_status(UpgradeStatus::default()/* use setters */);
pub fn set_or_clear_upgrade_status<T>(self, v: Option<T>) -> Self
where T: Into<UpgradeStatus>,

Sets or clears the value of upgrade_status.

Example
use google_cloud_vmmigration_v1::model::UpgradeStatus;
let x = DatacenterConnector::new().set_or_clear_upgrade_status(Some(UpgradeStatus::default()/* use setters */));
let x = DatacenterConnector::new().set_or_clear_upgrade_status(None::<UpgradeStatus>);