DiskMigrationJob

Struct DiskMigrationJob 

#[non_exhaustive]
pub struct DiskMigrationJob { pub name: String, pub target_details: Option<DiskMigrationJobTargetDetails>, pub create_time: Option<Timestamp>, pub update_time: Option<Timestamp>, pub state: State, pub errors: Vec<Status>, pub steps: Vec<DiskMigrationStep>, pub source_disk_details: Option<SourceDiskDetails>, /* private fields */ }
Describes the disk which will be migrated from the source environment. The source disk has to be unattached.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Output only. Identifier. The identifier of the DiskMigrationJob.

target_details: Option<DiskMigrationJobTargetDetails>

Required. Details of the target Disk in Compute Engine.

create_time: Option<Timestamp>

Output only. The time the DiskMigrationJob resource was created.

update_time: Option<Timestamp>

Output only. The last time the DiskMigrationJob resource was updated.

state: State

Output only. State of the DiskMigrationJob.

errors: Vec<Status>

Output only. Provides details on the errors that led to the disk migration job’s state in case of an error.

steps: Vec<DiskMigrationStep>

Output only. The disk migration steps list representing its progress.

source_disk_details: Option<SourceDiskDetails>

Unattached source disk details.

Implementations

Source

impl DiskMigrationJob

pub fn new() -> Self

Creates a new default instance.

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = DiskMigrationJob::new().set_name(format!("projects/{project_id}/locations/{location_id}/sources/{source_id}/diskMigrationJobs/{disk_migration_job_id}"));
pub fn set_target_details<T>(self, v: T) -> Self

Sets the value of target_details.

Example
use google_cloud_vmmigration_v1::model::DiskMigrationJobTargetDetails;
let x = DiskMigrationJob::new().set_target_details(DiskMigrationJobTargetDetails::default()/* use setters */);
pub fn set_or_clear_target_details<T>(self, v: Option<T>) -> Self

Sets or clears the value of target_details.

Example
use google_cloud_vmmigration_v1::model::DiskMigrationJobTargetDetails;
let x = DiskMigrationJob::new().set_or_clear_target_details(Some(DiskMigrationJobTargetDetails::default()/* use setters */));
let x = DiskMigrationJob::new().set_or_clear_target_details(None::<DiskMigrationJobTargetDetails>);
pub fn set_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of create_time.

Example
use wkt::Timestamp;
let x = DiskMigrationJob::new().set_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of create_time.

Example
use wkt::Timestamp;
let x = DiskMigrationJob::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = DiskMigrationJob::new().set_or_clear_create_time(None::<Timestamp>);
pub fn set_update_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of update_time.

Example
use wkt::Timestamp;
let x = DiskMigrationJob::new().set_update_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of update_time.

Example
use wkt::Timestamp;
let x = DiskMigrationJob::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = DiskMigrationJob::new().set_or_clear_update_time(None::<Timestamp>);
pub fn set_state<T: Into<State>>(self, v: T) -> Self

Sets the value of state.

Example
use google_cloud_vmmigration_v1::model::disk_migration_job::State;
let x0 = DiskMigrationJob::new().set_state(State::Ready);
let x1 = DiskMigrationJob::new().set_state(State::Running);
let x2 = DiskMigrationJob::new().set_state(State::Succeeded);
pub fn set_errors<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<Status>,

Sets the value of errors.

Example
use google_cloud_rpc::model::Status;
let x = DiskMigrationJob::new()
    .set_errors([
        Status::default()/* use setters */,
        Status::default()/* use (different) setters */,
    ]);
pub fn set_steps<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<DiskMigrationStep>,

Sets the value of steps.

Example
use google_cloud_vmmigration_v1::model::DiskMigrationStep;
let x = DiskMigrationJob::new()
    .set_steps([
        DiskMigrationStep::default()/* use setters */,
        DiskMigrationStep::default()/* use (different) setters */,
    ]);
pub fn set_source_disk_details<T: Into<Option<SourceDiskDetails>>>( self, v: T, ) -> Self

Sets the value of source_disk_details.

Note that all the setters affecting source_disk_details are mutually exclusive.

Example
use google_cloud_vmmigration_v1::model::AwsSourceDiskDetails;
let x = DiskMigrationJob::new().set_source_disk_details(Some(
    google_cloud_vmmigration_v1::model::disk_migration_job::SourceDiskDetails::AwsSourceDiskDetails(AwsSourceDiskDetails::default().into())));
pub fn aws_source_disk_details(&self) -> Option<&Box<AwsSourceDiskDetails>>

The value of source_disk_details if it holds a AwsSourceDiskDetails, None if the field is not set or holds a different branch.

pub fn set_aws_source_disk_details<T: Into<Box<AwsSourceDiskDetails>>>( self, v: T, ) -> Self

Sets the value of source_disk_details to hold a AwsSourceDiskDetails.

Note that all the setters affecting source_disk_details are mutually exclusive.

Example
use google_cloud_vmmigration_v1::model::AwsSourceDiskDetails;
let x = DiskMigrationJob::new().set_aws_source_disk_details(AwsSourceDiskDetails::default()/* use setters */);
assert!(x.aws_source_disk_details().is_some());