#[non_exhaustive]pub struct DiskMigrationStep {
pub start_time: Option<Timestamp>,
pub end_time: Option<Timestamp>,
pub step: Option<Step>,
/* private fields */
}Expand description
DiskMigrationStep holds information about the disk migration step progress.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.start_time: Option<Timestamp>Output only. The time the step has started.
end_time: Option<Timestamp>Output only. The time the step has ended.
step: Option<Step>The step details.
Implementations
Sourceimpl DiskMigrationStep
impl DiskMigrationStep
Sourcepub fn set_start_time<T>(self, v: T) -> Self
pub fn set_start_time<T>(self, v: T) -> Self
Sets the value of start_time.
Example
use wkt::Timestamp;
let x = DiskMigrationStep::new().set_start_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of start_time.
Example
use wkt::Timestamp;
let x = DiskMigrationStep::new().set_or_clear_start_time(Some(Timestamp::default()/* use setters */));
let x = DiskMigrationStep::new().set_or_clear_start_time(None::<Timestamp>);Sourcepub fn set_end_time<T>(self, v: T) -> Self
pub fn set_end_time<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
Sourcepub fn set_step<T: Into<Option<Step>>>(self, v: T) -> Self
pub fn set_step<T: Into<Option<Step>>>(self, v: T) -> Self
Sets the value of step.
Note that all the setters affecting step are mutually
exclusive.
Example
use google_cloud_vmmigration_v1::model::CreatingSourceDiskSnapshotStep;
let x = DiskMigrationStep::new().set_step(Some(
google_cloud_vmmigration_v1::model::disk_migration_step::Step::CreatingSourceDiskSnapshot(CreatingSourceDiskSnapshotStep::default().into())));Sourcepub fn creating_source_disk_snapshot(
&self,
) -> Option<&Box<CreatingSourceDiskSnapshotStep>>
pub fn creating_source_disk_snapshot( &self, ) -> Option<&Box<CreatingSourceDiskSnapshotStep>>
The value of step
if it holds a CreatingSourceDiskSnapshot, None if the field is not set or
holds a different branch.
Sourcepub fn set_creating_source_disk_snapshot<T: Into<Box<CreatingSourceDiskSnapshotStep>>>(
self,
v: T,
) -> Self
pub fn set_creating_source_disk_snapshot<T: Into<Box<CreatingSourceDiskSnapshotStep>>>( self, v: T, ) -> Self
Sets the value of step
to hold a CreatingSourceDiskSnapshot.
Note that all the setters affecting step are
mutually exclusive.
Example
use google_cloud_vmmigration_v1::model::CreatingSourceDiskSnapshotStep;
let x = DiskMigrationStep::new().set_creating_source_disk_snapshot(CreatingSourceDiskSnapshotStep::default()/* use setters */);
assert!(x.creating_source_disk_snapshot().is_some());
assert!(x.copying_source_disk_snapshot().is_none());
assert!(x.provisioning_target_disk().is_none());Sourcepub fn copying_source_disk_snapshot(
&self,
) -> Option<&Box<CopyingSourceDiskSnapshotStep>>
pub fn copying_source_disk_snapshot( &self, ) -> Option<&Box<CopyingSourceDiskSnapshotStep>>
The value of step
if it holds a CopyingSourceDiskSnapshot, None if the field is not set or
holds a different branch.
Sourcepub fn set_copying_source_disk_snapshot<T: Into<Box<CopyingSourceDiskSnapshotStep>>>(
self,
v: T,
) -> Self
pub fn set_copying_source_disk_snapshot<T: Into<Box<CopyingSourceDiskSnapshotStep>>>( self, v: T, ) -> Self
Sets the value of step
to hold a CopyingSourceDiskSnapshot.
Note that all the setters affecting step are
mutually exclusive.
Example
use google_cloud_vmmigration_v1::model::CopyingSourceDiskSnapshotStep;
let x = DiskMigrationStep::new().set_copying_source_disk_snapshot(CopyingSourceDiskSnapshotStep::default()/* use setters */);
assert!(x.copying_source_disk_snapshot().is_some());
assert!(x.creating_source_disk_snapshot().is_none());
assert!(x.provisioning_target_disk().is_none());Sourcepub fn provisioning_target_disk(
&self,
) -> Option<&Box<ProvisioningTargetDiskStep>>
pub fn provisioning_target_disk( &self, ) -> Option<&Box<ProvisioningTargetDiskStep>>
The value of step
if it holds a ProvisioningTargetDisk, None if the field is not set or
holds a different branch.
Sourcepub fn set_provisioning_target_disk<T: Into<Box<ProvisioningTargetDiskStep>>>(
self,
v: T,
) -> Self
pub fn set_provisioning_target_disk<T: Into<Box<ProvisioningTargetDiskStep>>>( self, v: T, ) -> Self
Sets the value of step
to hold a ProvisioningTargetDisk.
Note that all the setters affecting step are
mutually exclusive.
Example
use google_cloud_vmmigration_v1::model::ProvisioningTargetDiskStep;
let x = DiskMigrationStep::new().set_provisioning_target_disk(ProvisioningTargetDiskStep::default()/* use setters */);
assert!(x.provisioning_target_disk().is_some());
assert!(x.creating_source_disk_snapshot().is_none());
assert!(x.copying_source_disk_snapshot().is_none());Trait Implementations
Sourceimpl Clone for DiskMigrationStep
impl Clone for DiskMigrationStep
Sourcefn clone(&self) -> DiskMigrationStep
fn clone(&self) -> DiskMigrationStep
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DiskMigrationStep
impl Debug for DiskMigrationStep
Sourceimpl Default for DiskMigrationStep
impl Default for DiskMigrationStep
Sourcefn default() -> DiskMigrationStep
fn default() -> DiskMigrationStep
Sourceimpl Message for DiskMigrationStep
impl Message for DiskMigrationStep
Sourceimpl PartialEq for DiskMigrationStep
impl PartialEq for DiskMigrationStep
Sourcefn eq(&self, other: &DiskMigrationStep) -> bool
fn eq(&self, other: &DiskMigrationStep) -> bool
self and other values to be equal, and is used by ==.