DisksMigrationVmTargetDefaults

Struct DisksMigrationVmTargetDefaults 

#[non_exhaustive]
pub struct DisksMigrationVmTargetDefaults {
Show 16 fields pub vm_name: String, pub machine_type_series: String, pub machine_type: String, pub network_tags: Vec<String>, pub network_interfaces: Vec<NetworkInterface>, pub service_account: String, pub compute_scheduling: Option<ComputeScheduling>, pub secure_boot: bool, pub enable_vtpm: bool, pub enable_integrity_monitoring: bool, pub metadata: HashMap<String, String>, pub additional_licenses: Vec<String>, pub hostname: String, pub labels: HashMap<String, String>, pub boot_disk_defaults: Option<BootDiskDefaults>, pub encryption: Option<Encryption>, /* private fields */
}
Details for creation of a VM that migrated data disks will be attached to.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
vm_name: String

Required. The name of the VM to create.

machine_type_series: String

Optional. The machine type series to create the VM with. For presentation only.

machine_type: String

Required. The machine type to create the VM with.

network_tags: Vec<String>

Optional. A list of network tags to associate with the VM.

network_interfaces: Vec<NetworkInterface>

Optional. NICs to attach to the VM.

service_account: String

Optional. The service account to associate the VM with.

compute_scheduling: Option<ComputeScheduling>

Optional. Compute instance scheduling information (if empty default is used).

secure_boot: bool

Optional. Defines whether the instance has Secure Boot enabled. This can be set to true only if the VM boot option is EFI.

enable_vtpm: bool

Optional. Defines whether the instance has vTPM enabled.

enable_integrity_monitoring: bool

Optional. Defines whether the instance has integrity monitoring enabled.

metadata: HashMap<String, String>

Optional. The metadata key/value pairs to assign to the VM.

additional_licenses: Vec<String>

Optional. Additional licenses to assign to the VM.

hostname: String

Optional. The hostname to assign to the VM.

labels: HashMap<String, String>

Optional. A map of labels to associate with the VM.

boot_disk_defaults: Option<BootDiskDefaults>

Optional. Details of the boot disk of the VM.

encryption: Option<Encryption>

Optional. The encryption to apply to the VM.

Implementations

Source

impl DisksMigrationVmTargetDefaults

pub fn new() -> Self

Creates a new default instance.

pub fn set_vm_name<T: Into<String>>(self, v: T) -> Self

Sets the value of vm_name.

Example
let x = DisksMigrationVmTargetDefaults::new().set_vm_name("example");
pub fn set_machine_type_series<T: Into<String>>(self, v: T) -> Self

Sets the value of machine_type_series.

Example
let x = DisksMigrationVmTargetDefaults::new().set_machine_type_series("example");
pub fn set_machine_type<T: Into<String>>(self, v: T) -> Self

Sets the value of machine_type.

Example
let x = DisksMigrationVmTargetDefaults::new().set_machine_type("example");
pub fn set_network_tags<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of network_tags.

Example
let x = DisksMigrationVmTargetDefaults::new().set_network_tags(["a", "b", "c"]);
pub fn set_network_interfaces<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<NetworkInterface>,

Sets the value of network_interfaces.

Example
use google_cloud_vmmigration_v1::model::NetworkInterface;
let x = DisksMigrationVmTargetDefaults::new()
    .set_network_interfaces([
        NetworkInterface::default()/* use setters */,
        NetworkInterface::default()/* use (different) setters */,
    ]);
pub fn set_service_account<T: Into<String>>(self, v: T) -> Self

Sets the value of service_account.

Example
let x = DisksMigrationVmTargetDefaults::new().set_service_account("example");
pub fn set_compute_scheduling<T>(self, v: T) -> Self

Sets the value of compute_scheduling.

Example
use google_cloud_vmmigration_v1::model::ComputeScheduling;
let x = DisksMigrationVmTargetDefaults::new().set_compute_scheduling(ComputeScheduling::default()/* use setters */);
pub fn set_or_clear_compute_scheduling<T>(self, v: Option<T>) -> Self

Sets or clears the value of compute_scheduling.

Example
use google_cloud_vmmigration_v1::model::ComputeScheduling;
let x = DisksMigrationVmTargetDefaults::new().set_or_clear_compute_scheduling(Some(ComputeScheduling::default()/* use setters */));
let x = DisksMigrationVmTargetDefaults::new().set_or_clear_compute_scheduling(None::<ComputeScheduling>);
pub fn set_secure_boot<T: Into<bool>>(self, v: T) -> Self

Sets the value of secure_boot.

Example
let x = DisksMigrationVmTargetDefaults::new().set_secure_boot(true);
pub fn set_enable_vtpm<T: Into<bool>>(self, v: T) -> Self

Sets the value of enable_vtpm.

Example
let x = DisksMigrationVmTargetDefaults::new().set_enable_vtpm(true);
pub fn set_enable_integrity_monitoring<T: Into<bool>>(self, v: T) -> Self

Sets the value of enable_integrity_monitoring.

Example
let x = DisksMigrationVmTargetDefaults::new().set_enable_integrity_monitoring(true);
pub fn set_metadata<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of metadata.

Example
let x = DisksMigrationVmTargetDefaults::new().set_metadata([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_additional_licenses<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of additional_licenses.

Example
let x = DisksMigrationVmTargetDefaults::new().set_additional_licenses(["a", "b", "c"]);
pub fn set_hostname<T: Into<String>>(self, v: T) -> Self

Sets the value of hostname.

Example
let x = DisksMigrationVmTargetDefaults::new().set_hostname("example");
pub fn set_labels<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of labels.

Example
let x = DisksMigrationVmTargetDefaults::new().set_labels([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_boot_disk_defaults<T>(self, v: T) -> Self

Sets the value of boot_disk_defaults.

Example
use google_cloud_vmmigration_v1::model::BootDiskDefaults;
let x = DisksMigrationVmTargetDefaults::new().set_boot_disk_defaults(BootDiskDefaults::default()/* use setters */);
pub fn set_or_clear_boot_disk_defaults<T>(self, v: Option<T>) -> Self

Sets or clears the value of boot_disk_defaults.

Example
use google_cloud_vmmigration_v1::model::BootDiskDefaults;
let x = DisksMigrationVmTargetDefaults::new().set_or_clear_boot_disk_defaults(Some(BootDiskDefaults::default()/* use setters */));
let x = DisksMigrationVmTargetDefaults::new().set_or_clear_boot_disk_defaults(None::<BootDiskDefaults>);
pub fn set_encryption<T>(self, v: T) -> Self
where T: Into<Encryption>,

Sets the value of encryption.

Example
use google_cloud_vmmigration_v1::model::Encryption;
let x = DisksMigrationVmTargetDefaults::new().set_encryption(Encryption::default()/* use setters */);
pub fn set_or_clear_encryption<T>(self, v: Option<T>) -> Self
where T: Into<Encryption>,

Sets or clears the value of encryption.

Example
use google_cloud_vmmigration_v1::model::Encryption;
let x = DisksMigrationVmTargetDefaults::new().set_or_clear_encryption(Some(Encryption::default()/* use setters */));
let x = DisksMigrationVmTargetDefaults::new().set_or_clear_encryption(None::<Encryption>);