#[non_exhaustive]pub struct Encryption {
pub kms_key: String,
/* private fields */
}Expand description
Encryption message describes the details of the applied encryption.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.kms_key: StringRequired. The name of the encryption key that is stored in Google Cloud KMS.
Implementations