#[non_exhaustive]pub struct FetchInventoryRequest {
pub source: String,
pub force_refresh: bool,
/* private fields */
}Expand description
Request message for fetchInventory.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source: StringRequired. The name of the Source.
force_refresh: boolIf this flag is set to true, the source will be queried instead of using cached results. Using this flag will make the call slower.
Implementations
Sourceimpl FetchInventoryRequest
impl FetchInventoryRequest
Sourcepub fn set_source<T: Into<String>>(self, v: T) -> Self
pub fn set_source<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_force_refresh<T: Into<bool>>(self, v: T) -> Self
pub fn set_force_refresh<T: Into<bool>>(self, v: T) -> Self
Sets the value of force_refresh.
Example
ⓘ
let x = FetchInventoryRequest::new().set_force_refresh(true);Trait Implementations
Sourceimpl Clone for FetchInventoryRequest
impl Clone for FetchInventoryRequest
Sourcefn clone(&self) -> FetchInventoryRequest
fn clone(&self) -> FetchInventoryRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FetchInventoryRequest
impl Debug for FetchInventoryRequest
Sourceimpl Default for FetchInventoryRequest
impl Default for FetchInventoryRequest
Sourcefn default() -> FetchInventoryRequest
fn default() -> FetchInventoryRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for FetchInventoryRequest
impl Message for FetchInventoryRequest
Sourceimpl PartialEq for FetchInventoryRequest
impl PartialEq for FetchInventoryRequest
Sourcefn eq(&self, other: &FetchInventoryRequest) -> bool
fn eq(&self, other: &FetchInventoryRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for FetchInventoryRequest