#[non_exhaustive]pub struct FetchInventoryResponse {
pub update_time: Option<Timestamp>,
pub source_vms: Option<SourceVms>,
/* private fields */
}Expand description
Response message for fetchInventory.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_time: Option<Timestamp>Output only. The timestamp when the source was last queried (if the result is from the cache).
source_vms: Option<SourceVms>Implementations
Sourceimpl FetchInventoryResponse
impl FetchInventoryResponse
Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = FetchInventoryResponse::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = FetchInventoryResponse::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = FetchInventoryResponse::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_source_vms<T: Into<Option<SourceVms>>>(self, v: T) -> Self
pub fn set_source_vms<T: Into<Option<SourceVms>>>(self, v: T) -> Self
Sets the value of source_vms.
Note that all the setters affecting source_vms are mutually
exclusive.
Example
use google_cloud_vmmigration_v1::model::VmwareVmsDetails;
let x = FetchInventoryResponse::new().set_source_vms(Some(
google_cloud_vmmigration_v1::model::fetch_inventory_response::SourceVms::VmwareVms(VmwareVmsDetails::default().into())));Sourcepub fn vmware_vms(&self) -> Option<&Box<VmwareVmsDetails>>
pub fn vmware_vms(&self) -> Option<&Box<VmwareVmsDetails>>
The value of source_vms
if it holds a VmwareVms, None if the field is not set or
holds a different branch.
Sourcepub fn set_vmware_vms<T: Into<Box<VmwareVmsDetails>>>(self, v: T) -> Self
pub fn set_vmware_vms<T: Into<Box<VmwareVmsDetails>>>(self, v: T) -> Self
Sets the value of source_vms
to hold a VmwareVms.
Note that all the setters affecting source_vms are
mutually exclusive.
Example
use google_cloud_vmmigration_v1::model::VmwareVmsDetails;
let x = FetchInventoryResponse::new().set_vmware_vms(VmwareVmsDetails::default()/* use setters */);
assert!(x.vmware_vms().is_some());
assert!(x.aws_vms().is_none());
assert!(x.azure_vms().is_none());Sourcepub fn aws_vms(&self) -> Option<&Box<AwsVmsDetails>>
pub fn aws_vms(&self) -> Option<&Box<AwsVmsDetails>>
The value of source_vms
if it holds a AwsVms, None if the field is not set or
holds a different branch.
Sourcepub fn set_aws_vms<T: Into<Box<AwsVmsDetails>>>(self, v: T) -> Self
pub fn set_aws_vms<T: Into<Box<AwsVmsDetails>>>(self, v: T) -> Self
Sets the value of source_vms
to hold a AwsVms.
Note that all the setters affecting source_vms are
mutually exclusive.
Example
use google_cloud_vmmigration_v1::model::AwsVmsDetails;
let x = FetchInventoryResponse::new().set_aws_vms(AwsVmsDetails::default()/* use setters */);
assert!(x.aws_vms().is_some());
assert!(x.vmware_vms().is_none());
assert!(x.azure_vms().is_none());Sourcepub fn azure_vms(&self) -> Option<&Box<AzureVmsDetails>>
pub fn azure_vms(&self) -> Option<&Box<AzureVmsDetails>>
The value of source_vms
if it holds a AzureVms, None if the field is not set or
holds a different branch.
Sourcepub fn set_azure_vms<T: Into<Box<AzureVmsDetails>>>(self, v: T) -> Self
pub fn set_azure_vms<T: Into<Box<AzureVmsDetails>>>(self, v: T) -> Self
Sets the value of source_vms
to hold a AzureVms.
Note that all the setters affecting source_vms are
mutually exclusive.
Example
use google_cloud_vmmigration_v1::model::AzureVmsDetails;
let x = FetchInventoryResponse::new().set_azure_vms(AzureVmsDetails::default()/* use setters */);
assert!(x.azure_vms().is_some());
assert!(x.vmware_vms().is_none());
assert!(x.aws_vms().is_none());Trait Implementations
Sourceimpl Clone for FetchInventoryResponse
impl Clone for FetchInventoryResponse
Sourcefn clone(&self) -> FetchInventoryResponse
fn clone(&self) -> FetchInventoryResponse
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for FetchInventoryResponse
impl Debug for FetchInventoryResponse
Sourceimpl Default for FetchInventoryResponse
impl Default for FetchInventoryResponse
Sourcefn default() -> FetchInventoryResponse
fn default() -> FetchInventoryResponse
Sourceimpl Message for FetchInventoryResponse
impl Message for FetchInventoryResponse
Sourceimpl PartialEq for FetchInventoryResponse
impl PartialEq for FetchInventoryResponse
Sourcefn eq(&self, other: &FetchInventoryResponse) -> bool
fn eq(&self, other: &FetchInventoryResponse) -> bool
self and other values to be equal, and is used by ==.