#[non_exhaustive]pub struct FetchStorageInventoryRequest {
pub source: String,
pub type: StorageType,
pub force_refresh: bool,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
Request message for fetchStorageInventory.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source: StringRequired. The name of the Source.
type: StorageTypeRequired. The type of the storage inventory to fetch.
force_refresh: boolOptional. If this flag is set to true, the source will be queried instead of using cached results. Using this flag will make the call slower.
page_size: i32Optional. The maximum number of VMs to return. The service may return fewer than this value.
page_token: StringOptional. A page token, received from a previous FetchStorageInventory
call. Provide this to retrieve the subsequent page. When paginating, all
other parameters provided to FetchStorageInventory must match the call
that provided the page token.
Implementations
Sourceimpl FetchStorageInventoryRequest
impl FetchStorageInventoryRequest
Sourcepub fn set_source<T: Into<String>>(self, v: T) -> Self
pub fn set_source<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_type<T: Into<StorageType>>(self, v: T) -> Self
pub fn set_type<T: Into<StorageType>>(self, v: T) -> Self
Sourcepub fn set_force_refresh<T: Into<bool>>(self, v: T) -> Self
pub fn set_force_refresh<T: Into<bool>>(self, v: T) -> Self
Sets the value of force_refresh.
Example
ⓘ
let x = FetchStorageInventoryRequest::new().set_force_refresh(true);Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = FetchStorageInventoryRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for FetchStorageInventoryRequest
impl Clone for FetchStorageInventoryRequest
Sourcefn clone(&self) -> FetchStorageInventoryRequest
fn clone(&self) -> FetchStorageInventoryRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FetchStorageInventoryRequest
impl Debug for FetchStorageInventoryRequest
Sourceimpl Default for FetchStorageInventoryRequest
impl Default for FetchStorageInventoryRequest
Sourcefn default() -> FetchStorageInventoryRequest
fn default() -> FetchStorageInventoryRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for FetchStorageInventoryRequest
impl PartialEq for FetchStorageInventoryRequest
Sourcefn eq(&self, other: &FetchStorageInventoryRequest) -> bool
fn eq(&self, other: &FetchStorageInventoryRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for FetchStorageInventoryRequest