#[non_exhaustive]pub struct FetchStorageInventoryResponse {
pub resources: Vec<SourceStorageResource>,
pub update_time: Option<Timestamp>,
pub next_page_token: String,
/* private fields */
}Expand description
Response message for fetchStorageInventory.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resources: Vec<SourceStorageResource>The list of storage resources in the source.
update_time: Option<Timestamp>Output only. The timestamp when the source was last queried (if the result is from the cache).
next_page_token: StringOutput only. A token, which can be sent as page_token to retrieve the
next page. If this field is omitted, there are no subsequent pages.
Implementations
Sourceimpl FetchStorageInventoryResponse
impl FetchStorageInventoryResponse
Sourcepub fn set_resources<T, V>(self, v: T) -> Self
pub fn set_resources<T, V>(self, v: T) -> Self
Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
ⓘ
use wkt::Timestamp;
let x = FetchStorageInventoryResponse::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
ⓘ
use wkt::Timestamp;
let x = FetchStorageInventoryResponse::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = FetchStorageInventoryResponse::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = FetchStorageInventoryResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for FetchStorageInventoryResponse
impl Clone for FetchStorageInventoryResponse
Sourcefn clone(&self) -> FetchStorageInventoryResponse
fn clone(&self) -> FetchStorageInventoryResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for FetchStorageInventoryResponse
impl Default for FetchStorageInventoryResponse
Sourcefn default() -> FetchStorageInventoryResponse
fn default() -> FetchStorageInventoryResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for FetchStorageInventoryResponse
impl PartialEq for FetchStorageInventoryResponse
Sourcefn eq(&self, other: &FetchStorageInventoryResponse) -> bool
fn eq(&self, other: &FetchStorageInventoryResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for FetchStorageInventoryResponse