#[non_exhaustive]pub struct ImageImportJob {
pub name: String,
pub created_resources: Vec<String>,
pub state: State,
pub create_time: Option<Timestamp>,
pub end_time: Option<Timestamp>,
pub errors: Vec<Status>,
pub warnings: Vec<MigrationWarning>,
pub steps: Vec<ImageImportStep>,
pub source: Option<Source>,
pub target_details: Option<TargetDetails>,
/* private fields */
}Expand description
ImageImportJob describes the progress and result of an image import.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The resource path of the ImageImportJob.
created_resources: Vec<String>Output only. The resource paths of the resources created by the image import job.
state: StateOutput only. The state of the image import.
create_time: Option<Timestamp>Output only. The time the image import was created (as an API call, not when it was actually created in the target).
end_time: Option<Timestamp>Output only. The time the image import was ended.
errors: Vec<Status>Output only. Provides details on the error that led to the image import state in case of an error.
warnings: Vec<MigrationWarning>Output only. Warnings that occurred during the image import.
steps: Vec<ImageImportStep>Output only. The image import steps list representing its progress.
source: Option<Source>target_details: Option<TargetDetails>The configuration of the resources that were created in GCP as a result of the image import.
Implementations
Sourceimpl ImageImportJob
impl ImageImportJob
Sourcepub fn set_created_resources<T, V>(self, v: T) -> Self
pub fn set_created_resources<T, V>(self, v: T) -> Self
Sets the value of created_resources.
Example
let x = ImageImportJob::new().set_created_resources(["a", "b", "c"]);Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = ImageImportJob::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = ImageImportJob::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = ImageImportJob::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_end_time<T>(self, v: T) -> Self
pub fn set_end_time<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
Sourcepub fn set_errors<T, V>(self, v: T) -> Self
pub fn set_errors<T, V>(self, v: T) -> Self
Sourcepub fn set_warnings<T, V>(self, v: T) -> Self
pub fn set_warnings<T, V>(self, v: T) -> Self
Sourcepub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
pub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
Sourcepub fn cloud_storage_uri(&self) -> Option<&String>
pub fn cloud_storage_uri(&self) -> Option<&String>
The value of source
if it holds a CloudStorageUri, None if the field is not set or
holds a different branch.
Sourcepub fn set_cloud_storage_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_cloud_storage_uri<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_target_details<T: Into<Option<TargetDetails>>>(self, v: T) -> Self
pub fn set_target_details<T: Into<Option<TargetDetails>>>(self, v: T) -> Self
Sets the value of target_details.
Note that all the setters affecting target_details are mutually
exclusive.
Example
use google_cloud_vmmigration_v1::model::DiskImageTargetDetails;
let x = ImageImportJob::new().set_target_details(Some(
google_cloud_vmmigration_v1::model::image_import_job::TargetDetails::DiskImageTargetDetails(DiskImageTargetDetails::default().into())));Sourcepub fn disk_image_target_details(&self) -> Option<&Box<DiskImageTargetDetails>>
pub fn disk_image_target_details(&self) -> Option<&Box<DiskImageTargetDetails>>
The value of target_details
if it holds a DiskImageTargetDetails, None if the field is not set or
holds a different branch.
Sourcepub fn set_disk_image_target_details<T: Into<Box<DiskImageTargetDetails>>>(
self,
v: T,
) -> Self
pub fn set_disk_image_target_details<T: Into<Box<DiskImageTargetDetails>>>( self, v: T, ) -> Self
Sets the value of target_details
to hold a DiskImageTargetDetails.
Note that all the setters affecting target_details are
mutually exclusive.
Example
use google_cloud_vmmigration_v1::model::DiskImageTargetDetails;
let x = ImageImportJob::new().set_disk_image_target_details(DiskImageTargetDetails::default()/* use setters */);
assert!(x.disk_image_target_details().is_some());
assert!(x.machine_image_target_details().is_none());Sourcepub fn machine_image_target_details(
&self,
) -> Option<&Box<MachineImageTargetDetails>>
pub fn machine_image_target_details( &self, ) -> Option<&Box<MachineImageTargetDetails>>
The value of target_details
if it holds a MachineImageTargetDetails, None if the field is not set or
holds a different branch.
Sourcepub fn set_machine_image_target_details<T: Into<Box<MachineImageTargetDetails>>>(
self,
v: T,
) -> Self
pub fn set_machine_image_target_details<T: Into<Box<MachineImageTargetDetails>>>( self, v: T, ) -> Self
Sets the value of target_details
to hold a MachineImageTargetDetails.
Note that all the setters affecting target_details are
mutually exclusive.
Example
use google_cloud_vmmigration_v1::model::MachineImageTargetDetails;
let x = ImageImportJob::new().set_machine_image_target_details(MachineImageTargetDetails::default()/* use setters */);
assert!(x.machine_image_target_details().is_some());
assert!(x.disk_image_target_details().is_none());Trait Implementations
Sourceimpl Clone for ImageImportJob
impl Clone for ImageImportJob
Sourcefn clone(&self) -> ImageImportJob
fn clone(&self) -> ImageImportJob
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ImageImportJob
impl Debug for ImageImportJob
Sourceimpl Default for ImageImportJob
impl Default for ImageImportJob
Sourcefn default() -> ImageImportJob
fn default() -> ImageImportJob
Sourceimpl Message for ImageImportJob
impl Message for ImageImportJob
Sourceimpl PartialEq for ImageImportJob
impl PartialEq for ImageImportJob
Sourcefn eq(&self, other: &ImageImportJob) -> bool
fn eq(&self, other: &ImageImportJob) -> bool
self and other values to be equal, and is used by ==.