ImageImportOsAdaptationParameters

Struct ImageImportOsAdaptationParameters 

#[non_exhaustive]
pub struct ImageImportOsAdaptationParameters { pub generalize: bool, pub license_type: ComputeEngineLicenseType, pub boot_conversion: BootConversion, pub adaptation_modifiers: Vec<AdaptationModifier>, /* private fields */ }
Parameters affecting the OS adaptation process.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
generalize: bool

Optional. Set to true in order to generalize the imported image. The generalization process enables co-existence of multiple VMs created from the same image. For Windows, generalizing the image removes computer-specific information such as installed drivers and the computer security identifier (SID).

license_type: ComputeEngineLicenseType

Optional. Choose which type of license to apply to the imported image.

boot_conversion: BootConversion

Optional. By default the image will keep its existing boot option. Setting this property will trigger an internal process which will convert the image from using the existing boot option to another. The size of the boot disk might be increased to allow the conversion

adaptation_modifiers: Vec<AdaptationModifier>

Optional. Modifiers to be used as configuration of the OS adaptation process.

Implementations

Source

impl ImageImportOsAdaptationParameters

pub fn new() -> Self

Creates a new default instance.

pub fn set_generalize<T: Into<bool>>(self, v: T) -> Self

Sets the value of generalize.

Example
let x = ImageImportOsAdaptationParameters::new().set_generalize(true);
pub fn set_license_type<T: Into<ComputeEngineLicenseType>>(self, v: T) -> Self

Sets the value of license_type.

Example
use google_cloud_vmmigration_v1::model::ComputeEngineLicenseType;
let x0 = ImageImportOsAdaptationParameters::new().set_license_type(ComputeEngineLicenseType::Payg);
let x1 = ImageImportOsAdaptationParameters::new().set_license_type(ComputeEngineLicenseType::Byol);
pub fn set_boot_conversion<T: Into<BootConversion>>(self, v: T) -> Self

Sets the value of boot_conversion.

Example
use google_cloud_vmmigration_v1::model::BootConversion;
let x0 = ImageImportOsAdaptationParameters::new().set_boot_conversion(BootConversion::None);
let x1 = ImageImportOsAdaptationParameters::new().set_boot_conversion(BootConversion::BiosToEfi);
pub fn set_adaptation_modifiers<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<AdaptationModifier>,

Sets the value of adaptation_modifiers.

Example
use google_cloud_vmmigration_v1::model::AdaptationModifier;
let x = ImageImportOsAdaptationParameters::new()
    .set_adaptation_modifiers([
        AdaptationModifier::default()/* use setters */,
        AdaptationModifier::default()/* use (different) setters */,
    ]);