#[non_exhaustive]pub struct ImageImportStep {
pub start_time: Option<Timestamp>,
pub end_time: Option<Timestamp>,
pub step: Option<Step>,
/* private fields */
}Expand description
ImageImportStep holds information about the image import step progress.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.start_time: Option<Timestamp>Output only. The time the step has started.
end_time: Option<Timestamp>Output only. The time the step has ended.
step: Option<Step>Implementations
Sourceimpl ImageImportStep
impl ImageImportStep
Sourcepub fn set_start_time<T>(self, v: T) -> Self
pub fn set_start_time<T>(self, v: T) -> Self
Sets the value of start_time.
Example
use wkt::Timestamp;
let x = ImageImportStep::new().set_start_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of start_time.
Example
use wkt::Timestamp;
let x = ImageImportStep::new().set_or_clear_start_time(Some(Timestamp::default()/* use setters */));
let x = ImageImportStep::new().set_or_clear_start_time(None::<Timestamp>);Sourcepub fn set_end_time<T>(self, v: T) -> Self
pub fn set_end_time<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
Sourcepub fn set_step<T: Into<Option<Step>>>(self, v: T) -> Self
pub fn set_step<T: Into<Option<Step>>>(self, v: T) -> Self
Sets the value of step.
Note that all the setters affecting step are mutually
exclusive.
Example
use google_cloud_vmmigration_v1::model::InitializingImageImportStep;
let x = ImageImportStep::new().set_step(Some(
google_cloud_vmmigration_v1::model::image_import_step::Step::Initializing(InitializingImageImportStep::default().into())));Sourcepub fn initializing(&self) -> Option<&Box<InitializingImageImportStep>>
pub fn initializing(&self) -> Option<&Box<InitializingImageImportStep>>
The value of step
if it holds a Initializing, None if the field is not set or
holds a different branch.
Sourcepub fn set_initializing<T: Into<Box<InitializingImageImportStep>>>(
self,
v: T,
) -> Self
pub fn set_initializing<T: Into<Box<InitializingImageImportStep>>>( self, v: T, ) -> Self
Sets the value of step
to hold a Initializing.
Note that all the setters affecting step are
mutually exclusive.
Example
use google_cloud_vmmigration_v1::model::InitializingImageImportStep;
let x = ImageImportStep::new().set_initializing(InitializingImageImportStep::default()/* use setters */);
assert!(x.initializing().is_some());
assert!(x.loading_source_files().is_none());
assert!(x.adapting_os().is_none());
assert!(x.creating_image().is_none());Sourcepub fn loading_source_files(&self) -> Option<&Box<LoadingImageSourceFilesStep>>
pub fn loading_source_files(&self) -> Option<&Box<LoadingImageSourceFilesStep>>
The value of step
if it holds a LoadingSourceFiles, None if the field is not set or
holds a different branch.
Sourcepub fn set_loading_source_files<T: Into<Box<LoadingImageSourceFilesStep>>>(
self,
v: T,
) -> Self
pub fn set_loading_source_files<T: Into<Box<LoadingImageSourceFilesStep>>>( self, v: T, ) -> Self
Sets the value of step
to hold a LoadingSourceFiles.
Note that all the setters affecting step are
mutually exclusive.
Example
use google_cloud_vmmigration_v1::model::LoadingImageSourceFilesStep;
let x = ImageImportStep::new().set_loading_source_files(LoadingImageSourceFilesStep::default()/* use setters */);
assert!(x.loading_source_files().is_some());
assert!(x.initializing().is_none());
assert!(x.adapting_os().is_none());
assert!(x.creating_image().is_none());Sourcepub fn adapting_os(&self) -> Option<&Box<AdaptingOSStep>>
pub fn adapting_os(&self) -> Option<&Box<AdaptingOSStep>>
The value of step
if it holds a AdaptingOs, None if the field is not set or
holds a different branch.
Sourcepub fn set_adapting_os<T: Into<Box<AdaptingOSStep>>>(self, v: T) -> Self
pub fn set_adapting_os<T: Into<Box<AdaptingOSStep>>>(self, v: T) -> Self
Sets the value of step
to hold a AdaptingOs.
Note that all the setters affecting step are
mutually exclusive.
Example
use google_cloud_vmmigration_v1::model::AdaptingOSStep;
let x = ImageImportStep::new().set_adapting_os(AdaptingOSStep::default()/* use setters */);
assert!(x.adapting_os().is_some());
assert!(x.initializing().is_none());
assert!(x.loading_source_files().is_none());
assert!(x.creating_image().is_none());Sourcepub fn creating_image(&self) -> Option<&Box<CreatingImageStep>>
pub fn creating_image(&self) -> Option<&Box<CreatingImageStep>>
The value of step
if it holds a CreatingImage, None if the field is not set or
holds a different branch.
Sourcepub fn set_creating_image<T: Into<Box<CreatingImageStep>>>(self, v: T) -> Self
pub fn set_creating_image<T: Into<Box<CreatingImageStep>>>(self, v: T) -> Self
Sets the value of step
to hold a CreatingImage.
Note that all the setters affecting step are
mutually exclusive.
Example
use google_cloud_vmmigration_v1::model::CreatingImageStep;
let x = ImageImportStep::new().set_creating_image(CreatingImageStep::default()/* use setters */);
assert!(x.creating_image().is_some());
assert!(x.initializing().is_none());
assert!(x.loading_source_files().is_none());
assert!(x.adapting_os().is_none());Trait Implementations
Sourceimpl Clone for ImageImportStep
impl Clone for ImageImportStep
Sourcefn clone(&self) -> ImageImportStep
fn clone(&self) -> ImageImportStep
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ImageImportStep
impl Debug for ImageImportStep
Sourceimpl Default for ImageImportStep
impl Default for ImageImportStep
Sourcefn default() -> ImageImportStep
fn default() -> ImageImportStep
Sourceimpl Message for ImageImportStep
impl Message for ImageImportStep
Sourceimpl PartialEq for ImageImportStep
impl PartialEq for ImageImportStep
Sourcefn eq(&self, other: &ImageImportStep) -> bool
fn eq(&self, other: &ImageImportStep) -> bool
self and other values to be equal, and is used by ==.