#[non_exhaustive]pub struct ListDatacenterConnectorsResponse {
pub datacenter_connectors: Vec<DatacenterConnector>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
Response message for ‘ListDatacenterConnectors’ request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.datacenter_connectors: Vec<DatacenterConnector>Output only. The list of sources response.
next_page_token: StringOutput only. A token, which can be sent as page_token to retrieve the
next page. If this field is omitted, there are no subsequent pages.
unreachable: Vec<String>Output only. Locations that could not be reached.
Implementations
Sourceimpl ListDatacenterConnectorsResponse
impl ListDatacenterConnectorsResponse
Sourcepub fn set_datacenter_connectors<T, V>(self, v: T) -> Self
pub fn set_datacenter_connectors<T, V>(self, v: T) -> Self
Sets the value of datacenter_connectors.
Example
ⓘ
use google_cloud_vmmigration_v1::model::DatacenterConnector;
let x = ListDatacenterConnectorsResponse::new()
.set_datacenter_connectors([
DatacenterConnector::default()/* use setters */,
DatacenterConnector::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListDatacenterConnectorsResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListDatacenterConnectorsResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListDatacenterConnectorsResponse
impl Clone for ListDatacenterConnectorsResponse
Sourcefn clone(&self) -> ListDatacenterConnectorsResponse
fn clone(&self) -> ListDatacenterConnectorsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListDatacenterConnectorsResponse
impl Default for ListDatacenterConnectorsResponse
Sourcefn default() -> ListDatacenterConnectorsResponse
fn default() -> ListDatacenterConnectorsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListDatacenterConnectorsResponse
impl PartialEq for ListDatacenterConnectorsResponse
Sourcefn eq(&self, other: &ListDatacenterConnectorsResponse) -> bool
fn eq(&self, other: &ListDatacenterConnectorsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListDatacenterConnectorsResponse