#[non_exhaustive]pub struct ListGroupsResponse {
pub groups: Vec<Group>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
Response message for ‘ListGroups’ request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.groups: Vec<Group>Output only. The list of groups response.
next_page_token: StringOutput only. A token, which can be sent as page_token to retrieve the
next page. If this field is omitted, there are no subsequent pages.
unreachable: Vec<String>Output only. Locations that could not be reached.
Implementations
Sourceimpl ListGroupsResponse
impl ListGroupsResponse
Sourcepub fn set_groups<T, V>(self, v: T) -> Self
pub fn set_groups<T, V>(self, v: T) -> Self
Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListGroupsResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListGroupsResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListGroupsResponse
impl Clone for ListGroupsResponse
Sourcefn clone(&self) -> ListGroupsResponse
fn clone(&self) -> ListGroupsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListGroupsResponse
impl Debug for ListGroupsResponse
Sourceimpl Default for ListGroupsResponse
impl Default for ListGroupsResponse
Sourcefn default() -> ListGroupsResponse
fn default() -> ListGroupsResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for ListGroupsResponse
impl Message for ListGroupsResponse
Sourceimpl PartialEq for ListGroupsResponse
impl PartialEq for ListGroupsResponse
Sourcefn eq(&self, other: &ListGroupsResponse) -> bool
fn eq(&self, other: &ListGroupsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListGroupsResponse