#[non_exhaustive]pub struct ListImageImportJobsResponse {
pub image_import_jobs: Vec<ImageImportJob>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
Response message for ‘ListImageImportJobs’ call.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.image_import_jobs: Vec<ImageImportJob>Output only. The list of target response.
next_page_token: StringOutput only. A token, which can be sent as page_token to retrieve the
next page. If this field is omitted, there are no subsequent pages.
unreachable: Vec<String>Output only. Locations that could not be reached.
Implementations
Sourceimpl ListImageImportJobsResponse
impl ListImageImportJobsResponse
Sourcepub fn set_image_import_jobs<T, V>(self, v: T) -> Self
pub fn set_image_import_jobs<T, V>(self, v: T) -> Self
Sets the value of image_import_jobs.
Example
ⓘ
use google_cloud_vmmigration_v1::model::ImageImportJob;
let x = ListImageImportJobsResponse::new()
.set_image_import_jobs([
ImageImportJob::default()/* use setters */,
ImageImportJob::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListImageImportJobsResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListImageImportJobsResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListImageImportJobsResponse
impl Clone for ListImageImportJobsResponse
Sourcefn clone(&self) -> ListImageImportJobsResponse
fn clone(&self) -> ListImageImportJobsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListImageImportJobsResponse
impl Debug for ListImageImportJobsResponse
Sourceimpl Default for ListImageImportJobsResponse
impl Default for ListImageImportJobsResponse
Sourcefn default() -> ListImageImportJobsResponse
fn default() -> ListImageImportJobsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListImageImportJobsResponse
impl PartialEq for ListImageImportJobsResponse
Sourcefn eq(&self, other: &ListImageImportJobsResponse) -> bool
fn eq(&self, other: &ListImageImportJobsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListImageImportJobsResponse