#[non_exhaustive]pub struct ListMigratingVmsResponse {
pub migrating_vms: Vec<MigratingVm>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
Response message for ‘ListMigratingVms’ request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.migrating_vms: Vec<MigratingVm>Output only. The list of Migrating VMs response.
next_page_token: StringOutput only. A token, which can be sent as page_token to retrieve the
next page. If this field is omitted, there are no subsequent pages.
unreachable: Vec<String>Output only. Locations that could not be reached.
Implementations
Sourceimpl ListMigratingVmsResponse
impl ListMigratingVmsResponse
Sourcepub fn set_migrating_vms<T, V>(self, v: T) -> Self
pub fn set_migrating_vms<T, V>(self, v: T) -> Self
Sets the value of migrating_vms.
Example
ⓘ
use google_cloud_vmmigration_v1::model::MigratingVm;
let x = ListMigratingVmsResponse::new()
.set_migrating_vms([
MigratingVm::default()/* use setters */,
MigratingVm::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListMigratingVmsResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListMigratingVmsResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListMigratingVmsResponse
impl Clone for ListMigratingVmsResponse
Sourcefn clone(&self) -> ListMigratingVmsResponse
fn clone(&self) -> ListMigratingVmsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListMigratingVmsResponse
impl Debug for ListMigratingVmsResponse
Sourceimpl Default for ListMigratingVmsResponse
impl Default for ListMigratingVmsResponse
Sourcefn default() -> ListMigratingVmsResponse
fn default() -> ListMigratingVmsResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for ListMigratingVmsResponse
impl Message for ListMigratingVmsResponse
Sourceimpl PartialEq for ListMigratingVmsResponse
impl PartialEq for ListMigratingVmsResponse
Sourcefn eq(&self, other: &ListMigratingVmsResponse) -> bool
fn eq(&self, other: &ListMigratingVmsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListMigratingVmsResponse