#[non_exhaustive]pub struct ListReplicationCyclesResponse {
pub replication_cycles: Vec<ReplicationCycle>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
Response message for ‘ListReplicationCycles’ request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.replication_cycles: Vec<ReplicationCycle>Output only. The list of replication cycles response.
next_page_token: StringOutput only. A token, which can be sent as page_token to retrieve the
next page. If this field is omitted, there are no subsequent pages.
unreachable: Vec<String>Output only. Locations that could not be reached.
Implementations
Sourceimpl ListReplicationCyclesResponse
impl ListReplicationCyclesResponse
Sourcepub fn set_replication_cycles<T, V>(self, v: T) -> Self
pub fn set_replication_cycles<T, V>(self, v: T) -> Self
Sets the value of replication_cycles.
Example
ⓘ
use google_cloud_vmmigration_v1::model::ReplicationCycle;
let x = ListReplicationCyclesResponse::new()
.set_replication_cycles([
ReplicationCycle::default()/* use setters */,
ReplicationCycle::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListReplicationCyclesResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListReplicationCyclesResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListReplicationCyclesResponse
impl Clone for ListReplicationCyclesResponse
Sourcefn clone(&self) -> ListReplicationCyclesResponse
fn clone(&self) -> ListReplicationCyclesResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListReplicationCyclesResponse
impl Default for ListReplicationCyclesResponse
Sourcefn default() -> ListReplicationCyclesResponse
fn default() -> ListReplicationCyclesResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListReplicationCyclesResponse
impl PartialEq for ListReplicationCyclesResponse
Sourcefn eq(&self, other: &ListReplicationCyclesResponse) -> bool
fn eq(&self, other: &ListReplicationCyclesResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListReplicationCyclesResponse