#[non_exhaustive]pub struct ListSourcesResponse {
pub sources: Vec<Source>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
Response message for ‘ListSources’ request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.sources: Vec<Source>Output only. The list of sources response.
next_page_token: StringOutput only. A token, which can be sent as page_token to retrieve the
next page. If this field is omitted, there are no subsequent pages.
unreachable: Vec<String>Output only. Locations that could not be reached.
Implementations
Sourceimpl ListSourcesResponse
impl ListSourcesResponse
Sourcepub fn set_sources<T, V>(self, v: T) -> Self
pub fn set_sources<T, V>(self, v: T) -> Self
Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListSourcesResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListSourcesResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListSourcesResponse
impl Clone for ListSourcesResponse
Sourcefn clone(&self) -> ListSourcesResponse
fn clone(&self) -> ListSourcesResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListSourcesResponse
impl Debug for ListSourcesResponse
Sourceimpl Default for ListSourcesResponse
impl Default for ListSourcesResponse
Sourcefn default() -> ListSourcesResponse
fn default() -> ListSourcesResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for ListSourcesResponse
impl Message for ListSourcesResponse
Sourceimpl PartialEq for ListSourcesResponse
impl PartialEq for ListSourcesResponse
Sourcefn eq(&self, other: &ListSourcesResponse) -> bool
fn eq(&self, other: &ListSourcesResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListSourcesResponse