#[non_exhaustive]pub struct ListTargetProjectsResponse {
pub target_projects: Vec<TargetProject>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
Response message for ‘ListTargetProjects’ call.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.target_projects: Vec<TargetProject>Output only. The list of target response.
next_page_token: StringOutput only. A token, which can be sent as page_token to retrieve the
next page. If this field is omitted, there are no subsequent pages.
unreachable: Vec<String>Output only. Locations that could not be reached.
Implementations
Sourceimpl ListTargetProjectsResponse
impl ListTargetProjectsResponse
Sourcepub fn set_target_projects<T, V>(self, v: T) -> Self
pub fn set_target_projects<T, V>(self, v: T) -> Self
Sets the value of target_projects.
Example
ⓘ
use google_cloud_vmmigration_v1::model::TargetProject;
let x = ListTargetProjectsResponse::new()
.set_target_projects([
TargetProject::default()/* use setters */,
TargetProject::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListTargetProjectsResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListTargetProjectsResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListTargetProjectsResponse
impl Clone for ListTargetProjectsResponse
Sourcefn clone(&self) -> ListTargetProjectsResponse
fn clone(&self) -> ListTargetProjectsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListTargetProjectsResponse
impl Debug for ListTargetProjectsResponse
Sourceimpl Default for ListTargetProjectsResponse
impl Default for ListTargetProjectsResponse
Sourcefn default() -> ListTargetProjectsResponse
fn default() -> ListTargetProjectsResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for ListTargetProjectsResponse
impl Message for ListTargetProjectsResponse
Sourceimpl PartialEq for ListTargetProjectsResponse
impl PartialEq for ListTargetProjectsResponse
Sourcefn eq(&self, other: &ListTargetProjectsResponse) -> bool
fn eq(&self, other: &ListTargetProjectsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListTargetProjectsResponse