#[non_exhaustive]pub struct ListUtilizationReportsResponse {
pub utilization_reports: Vec<UtilizationReport>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
Response message for ‘ListUtilizationReports’ request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.utilization_reports: Vec<UtilizationReport>Output only. The list of reports.
next_page_token: StringOutput only. A token, which can be sent as page_token to retrieve the
next page. If this field is omitted, there are no subsequent pages.
unreachable: Vec<String>Output only. Locations that could not be reached.
Implementations
Sourceimpl ListUtilizationReportsResponse
impl ListUtilizationReportsResponse
Sourcepub fn set_utilization_reports<T, V>(self, v: T) -> Self
pub fn set_utilization_reports<T, V>(self, v: T) -> Self
Sets the value of utilization_reports.
Example
ⓘ
use google_cloud_vmmigration_v1::model::UtilizationReport;
let x = ListUtilizationReportsResponse::new()
.set_utilization_reports([
UtilizationReport::default()/* use setters */,
UtilizationReport::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListUtilizationReportsResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListUtilizationReportsResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListUtilizationReportsResponse
impl Clone for ListUtilizationReportsResponse
Sourcefn clone(&self) -> ListUtilizationReportsResponse
fn clone(&self) -> ListUtilizationReportsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListUtilizationReportsResponse
impl Default for ListUtilizationReportsResponse
Sourcefn default() -> ListUtilizationReportsResponse
fn default() -> ListUtilizationReportsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListUtilizationReportsResponse
impl PartialEq for ListUtilizationReportsResponse
Sourcefn eq(&self, other: &ListUtilizationReportsResponse) -> bool
fn eq(&self, other: &ListUtilizationReportsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListUtilizationReportsResponse