MachineImageTargetDetails

Struct MachineImageTargetDetails 

#[non_exhaustive]
pub struct MachineImageTargetDetails {
Show 13 fields pub machine_image_name: String, pub target_project: String, pub description: String, pub single_region_storage: bool, pub encryption: Option<Encryption>, pub machine_image_parameters_overrides: Option<MachineImageParametersOverrides>, pub service_account: Option<ServiceAccount>, pub additional_licenses: Vec<String>, pub labels: HashMap<String, String>, pub tags: Vec<String>, pub shielded_instance_config: Option<ShieldedInstanceConfig>, pub network_interfaces: Vec<NetworkInterface>, pub os_adaptation_config: Option<OsAdaptationConfig>, /* private fields */
}
The target details of the machine image resource that will be created by the image import job.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
machine_image_name: String

Required. The name of the machine image to be created.

target_project: String

Required. Reference to the TargetProject resource that represents the target project in which the imported machine image will be created.

description: String

Optional. An optional description of the machine image.

single_region_storage: bool

Optional. Set to true to set the machine image storageLocations to the single region of the import job. When false, the closest multi-region is selected.

encryption: Option<Encryption>

Immutable. The encryption to apply to the machine image. If the Image Import resource has an encryption, this field must be set to the same encryption key.

machine_image_parameters_overrides: Option<MachineImageParametersOverrides>

Optional. Parameters overriding decisions based on the source machine image configurations.

service_account: Option<ServiceAccount>

Optional. The service account to assign to the instance created by the machine image.

additional_licenses: Vec<String>labels: HashMap<String, String>

Optional. The labels to apply to the instance created by the machine image.

tags: Vec<String>

Optional. The tags to apply to the instance created by the machine image.

shielded_instance_config: Option<ShieldedInstanceConfig>

Optional. Shielded instance configuration.

network_interfaces: Vec<NetworkInterface>

Optional. The network interfaces to create with the instance created by the machine image. Internal and external IP addresses, and network tiers are ignored for machine image import.

os_adaptation_config: Option<OsAdaptationConfig>

Implementations

Source

impl MachineImageTargetDetails

pub fn new() -> Self

Creates a new default instance.

pub fn set_machine_image_name<T: Into<String>>(self, v: T) -> Self

Sets the value of machine_image_name.

Example
let x = MachineImageTargetDetails::new().set_machine_image_name("example");
pub fn set_target_project<T: Into<String>>(self, v: T) -> Self

Sets the value of target_project.

Example
let x = MachineImageTargetDetails::new().set_target_project(format!("projects/{project_id}/locations/{location_id}/targetProjects/{target_project_id}"));
pub fn set_description<T: Into<String>>(self, v: T) -> Self

Sets the value of description.

Example
let x = MachineImageTargetDetails::new().set_description("example");
pub fn set_single_region_storage<T: Into<bool>>(self, v: T) -> Self

Sets the value of single_region_storage.

Example
let x = MachineImageTargetDetails::new().set_single_region_storage(true);
pub fn set_encryption<T>(self, v: T) -> Self
where T: Into<Encryption>,

Sets the value of encryption.

Example
use google_cloud_vmmigration_v1::model::Encryption;
let x = MachineImageTargetDetails::new().set_encryption(Encryption::default()/* use setters */);
pub fn set_or_clear_encryption<T>(self, v: Option<T>) -> Self
where T: Into<Encryption>,

Sets or clears the value of encryption.

Example
use google_cloud_vmmigration_v1::model::Encryption;
let x = MachineImageTargetDetails::new().set_or_clear_encryption(Some(Encryption::default()/* use setters */));
let x = MachineImageTargetDetails::new().set_or_clear_encryption(None::<Encryption>);
pub fn set_machine_image_parameters_overrides<T>(self, v: T) -> Self

Sets the value of machine_image_parameters_overrides.

Example
use google_cloud_vmmigration_v1::model::MachineImageParametersOverrides;
let x = MachineImageTargetDetails::new().set_machine_image_parameters_overrides(MachineImageParametersOverrides::default()/* use setters */);
pub fn set_or_clear_machine_image_parameters_overrides<T>( self, v: Option<T>, ) -> Self

Sets or clears the value of machine_image_parameters_overrides.

Example
use google_cloud_vmmigration_v1::model::MachineImageParametersOverrides;
let x = MachineImageTargetDetails::new().set_or_clear_machine_image_parameters_overrides(Some(MachineImageParametersOverrides::default()/* use setters */));
let x = MachineImageTargetDetails::new().set_or_clear_machine_image_parameters_overrides(None::<MachineImageParametersOverrides>);
pub fn set_service_account<T>(self, v: T) -> Self
where T: Into<ServiceAccount>,

Sets the value of service_account.

Example
use google_cloud_vmmigration_v1::model::ServiceAccount;
let x = MachineImageTargetDetails::new().set_service_account(ServiceAccount::default()/* use setters */);
pub fn set_or_clear_service_account<T>(self, v: Option<T>) -> Self
where T: Into<ServiceAccount>,

Sets or clears the value of service_account.

Example
use google_cloud_vmmigration_v1::model::ServiceAccount;
let x = MachineImageTargetDetails::new().set_or_clear_service_account(Some(ServiceAccount::default()/* use setters */));
let x = MachineImageTargetDetails::new().set_or_clear_service_account(None::<ServiceAccount>);
pub fn set_additional_licenses<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of additional_licenses.

Example
let x = MachineImageTargetDetails::new().set_additional_licenses(["a", "b", "c"]);
pub fn set_labels<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of labels.

Example
let x = MachineImageTargetDetails::new().set_labels([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_tags<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of tags.

Example
let x = MachineImageTargetDetails::new().set_tags(["a", "b", "c"]);
pub fn set_shielded_instance_config<T>(self, v: T) -> Self

Sets the value of shielded_instance_config.

Example
use google_cloud_vmmigration_v1::model::ShieldedInstanceConfig;
let x = MachineImageTargetDetails::new().set_shielded_instance_config(ShieldedInstanceConfig::default()/* use setters */);
pub fn set_or_clear_shielded_instance_config<T>(self, v: Option<T>) -> Self

Sets or clears the value of shielded_instance_config.

Example
use google_cloud_vmmigration_v1::model::ShieldedInstanceConfig;
let x = MachineImageTargetDetails::new().set_or_clear_shielded_instance_config(Some(ShieldedInstanceConfig::default()/* use setters */));
let x = MachineImageTargetDetails::new().set_or_clear_shielded_instance_config(None::<ShieldedInstanceConfig>);
pub fn set_network_interfaces<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<NetworkInterface>,

Sets the value of network_interfaces.

Example
use google_cloud_vmmigration_v1::model::NetworkInterface;
let x = MachineImageTargetDetails::new()
    .set_network_interfaces([
        NetworkInterface::default()/* use setters */,
        NetworkInterface::default()/* use (different) setters */,
    ]);
pub fn set_os_adaptation_config<T: Into<Option<OsAdaptationConfig>>>( self, v: T, ) -> Self

Sets the value of os_adaptation_config.

Note that all the setters affecting os_adaptation_config are mutually exclusive.

Example
use google_cloud_vmmigration_v1::model::ImageImportOsAdaptationParameters;
let x = MachineImageTargetDetails::new().set_os_adaptation_config(Some(
    google_cloud_vmmigration_v1::model::machine_image_target_details::OsAdaptationConfig::OsAdaptationParameters(ImageImportOsAdaptationParameters::default().into())));
pub fn os_adaptation_parameters( &self, ) -> Option<&Box<ImageImportOsAdaptationParameters>>

The value of os_adaptation_config if it holds a OsAdaptationParameters, None if the field is not set or holds a different branch.

pub fn set_os_adaptation_parameters<T: Into<Box<ImageImportOsAdaptationParameters>>>( self, v: T, ) -> Self

Sets the value of os_adaptation_config to hold a OsAdaptationParameters.

Note that all the setters affecting os_adaptation_config are mutually exclusive.

Example
use google_cloud_vmmigration_v1::model::ImageImportOsAdaptationParameters;
let x = MachineImageTargetDetails::new().set_os_adaptation_parameters(ImageImportOsAdaptationParameters::default()/* use setters */);
assert!(x.os_adaptation_parameters().is_some());
assert!(x.skip_os_adaptation().is_none());
pub fn skip_os_adaptation(&self) -> Option<&Box<SkipOsAdaptation>>

The value of os_adaptation_config if it holds a SkipOsAdaptation, None if the field is not set or holds a different branch.

pub fn set_skip_os_adaptation<T: Into<Box<SkipOsAdaptation>>>( self, v: T, ) -> Self

Sets the value of os_adaptation_config to hold a SkipOsAdaptation.

Note that all the setters affecting os_adaptation_config are mutually exclusive.

Example
use google_cloud_vmmigration_v1::model::SkipOsAdaptation;
let x = MachineImageTargetDetails::new().set_skip_os_adaptation(SkipOsAdaptation::default()/* use setters */);
assert!(x.skip_os_adaptation().is_some());
assert!(x.os_adaptation_parameters().is_none());