#[non_exhaustive]pub struct ReplicatingStep {
pub total_bytes: i64,
pub replicated_bytes: i64,
pub last_two_minutes_average_bytes_per_second: i64,
pub last_thirty_minutes_average_bytes_per_second: i64,
/* private fields */
}Expand description
ReplicatingStep contains specific step details.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.total_bytes: i64Total bytes to be handled in the step.
replicated_bytes: i64Replicated bytes in the step.
last_two_minutes_average_bytes_per_second: i64The source disks replication rate for the last 2 minutes in bytes per second.
last_thirty_minutes_average_bytes_per_second: i64The source disks replication rate for the last 30 minutes in bytes per second.
Implementations
Sourceimpl ReplicatingStep
impl ReplicatingStep
Sourcepub fn set_total_bytes<T: Into<i64>>(self, v: T) -> Self
pub fn set_total_bytes<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_replicated_bytes<T: Into<i64>>(self, v: T) -> Self
pub fn set_replicated_bytes<T: Into<i64>>(self, v: T) -> Self
Sets the value of replicated_bytes.
Example
ⓘ
let x = ReplicatingStep::new().set_replicated_bytes(42);Sourcepub fn set_last_two_minutes_average_bytes_per_second<T: Into<i64>>(
self,
v: T,
) -> Self
pub fn set_last_two_minutes_average_bytes_per_second<T: Into<i64>>( self, v: T, ) -> Self
Sets the value of last_two_minutes_average_bytes_per_second.
Example
ⓘ
let x = ReplicatingStep::new().set_last_two_minutes_average_bytes_per_second(42);Sourcepub fn set_last_thirty_minutes_average_bytes_per_second<T: Into<i64>>(
self,
v: T,
) -> Self
pub fn set_last_thirty_minutes_average_bytes_per_second<T: Into<i64>>( self, v: T, ) -> Self
Sets the value of last_thirty_minutes_average_bytes_per_second.
Example
ⓘ
let x = ReplicatingStep::new().set_last_thirty_minutes_average_bytes_per_second(42);Trait Implementations
Sourceimpl Clone for ReplicatingStep
impl Clone for ReplicatingStep
Sourcefn clone(&self) -> ReplicatingStep
fn clone(&self) -> ReplicatingStep
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReplicatingStep
impl Debug for ReplicatingStep
Sourceimpl Default for ReplicatingStep
impl Default for ReplicatingStep
Sourcefn default() -> ReplicatingStep
fn default() -> ReplicatingStep
Returns the “default value” for a type. Read more
Sourceimpl Message for ReplicatingStep
impl Message for ReplicatingStep
Sourceimpl PartialEq for ReplicatingStep
impl PartialEq for ReplicatingStep
Sourcefn eq(&self, other: &ReplicatingStep) -> bool
fn eq(&self, other: &ReplicatingStep) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ReplicatingStep