#[non_exhaustive]pub struct ReplicationCycle {
pub name: String,
pub cycle_number: i32,
pub start_time: Option<Timestamp>,
pub end_time: Option<Timestamp>,
pub total_pause_duration: Option<Duration>,
pub progress_percent: i32,
pub steps: Vec<CycleStep>,
pub state: State,
pub error: Option<Status>,
pub warnings: Vec<MigrationWarning>,
/* private fields */
}Expand description
ReplicationCycle contains information about the current replication cycle status.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe identifier of the ReplicationCycle.
cycle_number: i32The cycle’s ordinal number.
start_time: Option<Timestamp>The time the replication cycle has started.
end_time: Option<Timestamp>The time the replication cycle has ended.
total_pause_duration: Option<Duration>The accumulated duration the replication cycle was paused.
progress_percent: i32The current progress in percentage of this cycle. Was replaced by ‘steps’ field, which breaks down the cycle progression more accurately.
steps: Vec<CycleStep>The cycle’s steps list representing its progress.
state: StateState of the ReplicationCycle.
error: Option<Status>Output only. Provides details on the state of the cycle in case of an error.
warnings: Vec<MigrationWarning>Output only. Warnings that occurred during the cycle.
Implementations
Sourceimpl ReplicationCycle
impl ReplicationCycle
Sourcepub fn set_cycle_number<T: Into<i32>>(self, v: T) -> Self
pub fn set_cycle_number<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_start_time<T>(self, v: T) -> Self
pub fn set_start_time<T>(self, v: T) -> Self
Sets the value of start_time.
Example
use wkt::Timestamp;
let x = ReplicationCycle::new().set_start_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of start_time.
Example
use wkt::Timestamp;
let x = ReplicationCycle::new().set_or_clear_start_time(Some(Timestamp::default()/* use setters */));
let x = ReplicationCycle::new().set_or_clear_start_time(None::<Timestamp>);Sourcepub fn set_end_time<T>(self, v: T) -> Self
pub fn set_end_time<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
Sourcepub fn set_total_pause_duration<T>(self, v: T) -> Self
pub fn set_total_pause_duration<T>(self, v: T) -> Self
Sets the value of total_pause_duration.
Example
use wkt::Duration;
let x = ReplicationCycle::new().set_total_pause_duration(Duration::default()/* use setters */);Sourcepub fn set_or_clear_total_pause_duration<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_total_pause_duration<T>(self, v: Option<T>) -> Self
Sets or clears the value of total_pause_duration.
Example
use wkt::Duration;
let x = ReplicationCycle::new().set_or_clear_total_pause_duration(Some(Duration::default()/* use setters */));
let x = ReplicationCycle::new().set_or_clear_total_pause_duration(None::<Duration>);Sourcepub fn set_progress_percent<T: Into<i32>>(self, v: T) -> Self
👎Deprecated
pub fn set_progress_percent<T: Into<i32>>(self, v: T) -> Self
Sets the value of progress_percent.
Example
let x = ReplicationCycle::new().set_progress_percent(42);Sourcepub fn set_or_clear_error<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_error<T>(self, v: Option<T>) -> Self
Sourcepub fn set_warnings<T, V>(self, v: T) -> Self
pub fn set_warnings<T, V>(self, v: T) -> Self