#[non_exhaustive]pub struct ReplicationSync {
pub last_sync_time: Option<Timestamp>,
/* private fields */
}Expand description
ReplicationSync contain information about the last replica sync to the cloud.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.last_sync_time: Option<Timestamp>The most updated snapshot created time in the source that finished replication.
Implementations
Sourceimpl ReplicationSync
impl ReplicationSync
Sourcepub fn set_last_sync_time<T>(self, v: T) -> Self
pub fn set_last_sync_time<T>(self, v: T) -> Self
Sets the value of last_sync_time.
Example
ⓘ
use wkt::Timestamp;
let x = ReplicationSync::new().set_last_sync_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_last_sync_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_last_sync_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of last_sync_time.
Example
ⓘ
use wkt::Timestamp;
let x = ReplicationSync::new().set_or_clear_last_sync_time(Some(Timestamp::default()/* use setters */));
let x = ReplicationSync::new().set_or_clear_last_sync_time(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for ReplicationSync
impl Clone for ReplicationSync
Sourcefn clone(&self) -> ReplicationSync
fn clone(&self) -> ReplicationSync
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReplicationSync
impl Debug for ReplicationSync
Sourceimpl Default for ReplicationSync
impl Default for ReplicationSync
Sourcefn default() -> ReplicationSync
fn default() -> ReplicationSync
Returns the “default value” for a type. Read more
Sourceimpl Message for ReplicationSync
impl Message for ReplicationSync
Sourceimpl PartialEq for ReplicationSync
impl PartialEq for ReplicationSync
Sourcefn eq(&self, other: &ReplicationSync) -> bool
fn eq(&self, other: &ReplicationSync) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ReplicationSync