#[non_exhaustive]pub struct SchedulingNodeAffinity {
pub key: String,
pub operator: Operator,
pub values: Vec<String>,
/* private fields */
}Expand description
Node Affinity: the configuration of desired nodes onto which this Instance could be scheduled. Based on https://cloud.google.com/compute/docs/reference/rest/v1/instances/setScheduling
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.key: StringThe label key of Node resource to reference.
operator: OperatorThe operator to use for the node resources specified in the values
parameter.
values: Vec<String>Corresponds to the label values of Node resource.
Implementations
Sourceimpl SchedulingNodeAffinity
impl SchedulingNodeAffinity
Sourcepub fn set_operator<T: Into<Operator>>(self, v: T) -> Self
pub fn set_operator<T: Into<Operator>>(self, v: T) -> Self
Sourcepub fn set_values<T, V>(self, v: T) -> Self
pub fn set_values<T, V>(self, v: T) -> Self