#[non_exhaustive]pub struct ServiceAccount {
pub email: String,
pub scopes: Vec<String>,
/* private fields */
}Expand description
Service account to assign to the instance created by the machine image.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.email: StringRequired. The email address of the service account.
scopes: Vec<String>Optional. The list of scopes to be made available for this service account.
Implementations
Sourceimpl ServiceAccount
impl ServiceAccount