#[non_exhaustive]pub struct ShieldedInstanceConfig {
pub secure_boot: SecureBoot,
pub enable_vtpm: bool,
pub enable_integrity_monitoring: bool,
/* private fields */
}Expand description
Shielded instance configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.secure_boot: SecureBootOptional. Defines whether the instance created by the machine image has Secure Boot enabled. This can be set to true only if the image boot option is EFI.
enable_vtpm: boolOptional. Defines whether the instance created by the machine image has vTPM enabled. This can be set to true only if the image boot option is EFI.
enable_integrity_monitoring: boolOptional. Defines whether the instance created by the machine image has integrity monitoring enabled. This can be set to true only if the image boot option is EFI, and vTPM is enabled.
Implementations
Sourceimpl ShieldedInstanceConfig
impl ShieldedInstanceConfig
Sourcepub fn set_secure_boot<T: Into<SecureBoot>>(self, v: T) -> Self
pub fn set_secure_boot<T: Into<SecureBoot>>(self, v: T) -> Self
Sets the value of secure_boot.
Example
ⓘ
use google_cloud_vmmigration_v1::model::shielded_instance_config::SecureBoot;
let x0 = ShieldedInstanceConfig::new().set_secure_boot(SecureBoot::True);
let x1 = ShieldedInstanceConfig::new().set_secure_boot(SecureBoot::False);Sourcepub fn set_enable_vtpm<T: Into<bool>>(self, v: T) -> Self
pub fn set_enable_vtpm<T: Into<bool>>(self, v: T) -> Self
Sets the value of enable_vtpm.
Example
ⓘ
let x = ShieldedInstanceConfig::new().set_enable_vtpm(true);Sourcepub fn set_enable_integrity_monitoring<T: Into<bool>>(self, v: T) -> Self
pub fn set_enable_integrity_monitoring<T: Into<bool>>(self, v: T) -> Self
Sets the value of enable_integrity_monitoring.
Example
ⓘ
let x = ShieldedInstanceConfig::new().set_enable_integrity_monitoring(true);Trait Implementations
Sourceimpl Clone for ShieldedInstanceConfig
impl Clone for ShieldedInstanceConfig
Sourcefn clone(&self) -> ShieldedInstanceConfig
fn clone(&self) -> ShieldedInstanceConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShieldedInstanceConfig
impl Debug for ShieldedInstanceConfig
Sourceimpl Default for ShieldedInstanceConfig
impl Default for ShieldedInstanceConfig
Sourcefn default() -> ShieldedInstanceConfig
fn default() -> ShieldedInstanceConfig
Returns the “default value” for a type. Read more
Sourceimpl Message for ShieldedInstanceConfig
impl Message for ShieldedInstanceConfig
Sourceimpl PartialEq for ShieldedInstanceConfig
impl PartialEq for ShieldedInstanceConfig
Sourcefn eq(&self, other: &ShieldedInstanceConfig) -> bool
fn eq(&self, other: &ShieldedInstanceConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ShieldedInstanceConfig