#[non_exhaustive]pub struct TargetProject {
pub name: String,
pub project: String,
pub description: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
/* private fields */
}Expand description
TargetProject message represents a target Compute Engine project for a migration or a clone.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The name of the target project.
project: StringRequired. The target project ID (number) or project name.
description: StringThe target project’s description.
create_time: Option<Timestamp>Output only. The time this target project resource was created (not related to when the Compute Engine project it points to was created).
update_time: Option<Timestamp>Output only. The last time the target project resource was updated.
Implementations
Sourceimpl TargetProject
impl TargetProject
Sourcepub fn set_project<T: Into<String>>(self, v: T) -> Self
pub fn set_project<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
ⓘ
use wkt::Timestamp;
let x = TargetProject::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
ⓘ
use wkt::Timestamp;
let x = TargetProject::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = TargetProject::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
ⓘ
use wkt::Timestamp;
let x = TargetProject::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
ⓘ
use wkt::Timestamp;
let x = TargetProject::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = TargetProject::new().set_or_clear_update_time(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for TargetProject
impl Clone for TargetProject
Sourcefn clone(&self) -> TargetProject
fn clone(&self) -> TargetProject
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TargetProject
impl Debug for TargetProject
Sourceimpl Default for TargetProject
impl Default for TargetProject
Sourcefn default() -> TargetProject
fn default() -> TargetProject
Returns the “default value” for a type. Read more
Sourceimpl Message for TargetProject
impl Message for TargetProject
Sourceimpl PartialEq for TargetProject
impl PartialEq for TargetProject
Sourcefn eq(&self, other: &TargetProject) -> bool
fn eq(&self, other: &TargetProject) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TargetProject