#[non_exhaustive]pub struct UpdateDiskMigrationJobRequest {
pub update_mask: Option<FieldMask>,
pub disk_migration_job: Option<DiskMigrationJob>,
pub request_id: String,
/* private fields */
}Expand description
Request message for ‘UpdateDiskMigrationJob’ request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_mask: Option<FieldMask>Optional. Field mask is used to specify the fields to be overwritten in the DiskMigrationJob resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask, then a mask equivalent to all fields that are populated (have a non-empty value), will be implied.
disk_migration_job: Option<DiskMigrationJob>Required. The update request body.
request_id: StringOptional. A request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request timed out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl UpdateDiskMigrationJobRequest
impl UpdateDiskMigrationJobRequest
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateDiskMigrationJobRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateDiskMigrationJobRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateDiskMigrationJobRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_disk_migration_job<T>(self, v: T) -> Selfwhere
T: Into<DiskMigrationJob>,
pub fn set_disk_migration_job<T>(self, v: T) -> Selfwhere
T: Into<DiskMigrationJob>,
Sets the value of disk_migration_job.
Example
use google_cloud_vmmigration_v1::model::DiskMigrationJob;
let x = UpdateDiskMigrationJobRequest::new().set_disk_migration_job(DiskMigrationJob::default()/* use setters */);Sourcepub fn set_or_clear_disk_migration_job<T>(self, v: Option<T>) -> Selfwhere
T: Into<DiskMigrationJob>,
pub fn set_or_clear_disk_migration_job<T>(self, v: Option<T>) -> Selfwhere
T: Into<DiskMigrationJob>,
Sets or clears the value of disk_migration_job.
Example
use google_cloud_vmmigration_v1::model::DiskMigrationJob;
let x = UpdateDiskMigrationJobRequest::new().set_or_clear_disk_migration_job(Some(DiskMigrationJob::default()/* use setters */));
let x = UpdateDiskMigrationJobRequest::new().set_or_clear_disk_migration_job(None::<DiskMigrationJob>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = UpdateDiskMigrationJobRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for UpdateDiskMigrationJobRequest
impl Clone for UpdateDiskMigrationJobRequest
Sourcefn clone(&self) -> UpdateDiskMigrationJobRequest
fn clone(&self) -> UpdateDiskMigrationJobRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for UpdateDiskMigrationJobRequest
impl Default for UpdateDiskMigrationJobRequest
Sourcefn default() -> UpdateDiskMigrationJobRequest
fn default() -> UpdateDiskMigrationJobRequest
Sourceimpl PartialEq for UpdateDiskMigrationJobRequest
impl PartialEq for UpdateDiskMigrationJobRequest
Sourcefn eq(&self, other: &UpdateDiskMigrationJobRequest) -> bool
fn eq(&self, other: &UpdateDiskMigrationJobRequest) -> bool
self and other values to be equal, and is used by ==.