#[non_exhaustive]pub struct UpdateGroupRequest {
pub update_mask: Option<FieldMask>,
pub group: Option<Group>,
pub request_id: String,
/* private fields */
}Expand description
Update message for ‘UpdateGroups’ request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_mask: Option<FieldMask>Field mask is used to specify the fields to be overwritten in the Group resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then all fields will be overwritten.
group: Option<Group>Required. The update request body.
request_id: StringA request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl UpdateGroupRequest
impl UpdateGroupRequest
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateGroupRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateGroupRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateGroupRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_or_clear_group<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_group<T>(self, v: Option<T>) -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = UpdateGroupRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for UpdateGroupRequest
impl Clone for UpdateGroupRequest
Sourcefn clone(&self) -> UpdateGroupRequest
fn clone(&self) -> UpdateGroupRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for UpdateGroupRequest
impl Debug for UpdateGroupRequest
Sourceimpl Default for UpdateGroupRequest
impl Default for UpdateGroupRequest
Sourcefn default() -> UpdateGroupRequest
fn default() -> UpdateGroupRequest
Sourceimpl Message for UpdateGroupRequest
impl Message for UpdateGroupRequest
Sourceimpl PartialEq for UpdateGroupRequest
impl PartialEq for UpdateGroupRequest
Sourcefn eq(&self, other: &UpdateGroupRequest) -> bool
fn eq(&self, other: &UpdateGroupRequest) -> bool
self and other values to be equal, and is used by ==.