#[non_exhaustive]pub struct UpdateMigratingVmRequest {
pub update_mask: Option<FieldMask>,
pub migrating_vm: Option<MigratingVm>,
pub request_id: String,
/* private fields */
}Expand description
Request message for ‘UpdateMigratingVm’ request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_mask: Option<FieldMask>Field mask is used to specify the fields to be overwritten in the MigratingVm resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then all fields will be overwritten.
migrating_vm: Option<MigratingVm>Required. The update request body.
request_id: StringA request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl UpdateMigratingVmRequest
impl UpdateMigratingVmRequest
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateMigratingVmRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateMigratingVmRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateMigratingVmRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_migrating_vm<T>(self, v: T) -> Selfwhere
T: Into<MigratingVm>,
pub fn set_migrating_vm<T>(self, v: T) -> Selfwhere
T: Into<MigratingVm>,
Sets the value of migrating_vm.
Example
use google_cloud_vmmigration_v1::model::MigratingVm;
let x = UpdateMigratingVmRequest::new().set_migrating_vm(MigratingVm::default()/* use setters */);Sourcepub fn set_or_clear_migrating_vm<T>(self, v: Option<T>) -> Selfwhere
T: Into<MigratingVm>,
pub fn set_or_clear_migrating_vm<T>(self, v: Option<T>) -> Selfwhere
T: Into<MigratingVm>,
Sets or clears the value of migrating_vm.
Example
use google_cloud_vmmigration_v1::model::MigratingVm;
let x = UpdateMigratingVmRequest::new().set_or_clear_migrating_vm(Some(MigratingVm::default()/* use setters */));
let x = UpdateMigratingVmRequest::new().set_or_clear_migrating_vm(None::<MigratingVm>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = UpdateMigratingVmRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for UpdateMigratingVmRequest
impl Clone for UpdateMigratingVmRequest
Sourcefn clone(&self) -> UpdateMigratingVmRequest
fn clone(&self) -> UpdateMigratingVmRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for UpdateMigratingVmRequest
impl Debug for UpdateMigratingVmRequest
Sourceimpl Default for UpdateMigratingVmRequest
impl Default for UpdateMigratingVmRequest
Sourcefn default() -> UpdateMigratingVmRequest
fn default() -> UpdateMigratingVmRequest
Sourceimpl Message for UpdateMigratingVmRequest
impl Message for UpdateMigratingVmRequest
Sourceimpl PartialEq for UpdateMigratingVmRequest
impl PartialEq for UpdateMigratingVmRequest
Sourcefn eq(&self, other: &UpdateMigratingVmRequest) -> bool
fn eq(&self, other: &UpdateMigratingVmRequest) -> bool
self and other values to be equal, and is used by ==.