#[non_exhaustive]pub struct UpgradeStatus {
pub version: String,
pub state: State,
pub error: Option<Status>,
pub start_time: Option<Timestamp>,
pub previous_version: String,
/* private fields */
}Expand description
UpgradeStatus contains information about upgradeAppliance operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.version: StringThe version to upgrade to.
state: StateThe state of the upgradeAppliance operation.
error: Option<Status>Output only. Provides details on the state of the upgrade operation in case of an error.
start_time: Option<Timestamp>The time the operation was started.
previous_version: StringThe version from which we upgraded.
Implementations
Sourceimpl UpgradeStatus
impl UpgradeStatus
Sourcepub fn set_version<T: Into<String>>(self, v: T) -> Self
pub fn set_version<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_or_clear_error<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_error<T>(self, v: Option<T>) -> Self
Sourcepub fn set_start_time<T>(self, v: T) -> Self
pub fn set_start_time<T>(self, v: T) -> Self
Sets the value of start_time.
Example
ⓘ
use wkt::Timestamp;
let x = UpgradeStatus::new().set_start_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of start_time.
Example
ⓘ
use wkt::Timestamp;
let x = UpgradeStatus::new().set_or_clear_start_time(Some(Timestamp::default()/* use setters */));
let x = UpgradeStatus::new().set_or_clear_start_time(None::<Timestamp>);Sourcepub fn set_previous_version<T: Into<String>>(self, v: T) -> Self
pub fn set_previous_version<T: Into<String>>(self, v: T) -> Self
Sets the value of previous_version.
Example
ⓘ
let x = UpgradeStatus::new().set_previous_version("example");Trait Implementations
Sourceimpl Clone for UpgradeStatus
impl Clone for UpgradeStatus
Sourcefn clone(&self) -> UpgradeStatus
fn clone(&self) -> UpgradeStatus
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpgradeStatus
impl Debug for UpgradeStatus
Sourceimpl Default for UpgradeStatus
impl Default for UpgradeStatus
Sourcefn default() -> UpgradeStatus
fn default() -> UpgradeStatus
Returns the “default value” for a type. Read more
Sourceimpl Message for UpgradeStatus
impl Message for UpgradeStatus
Sourceimpl PartialEq for UpgradeStatus
impl PartialEq for UpgradeStatus
Sourcefn eq(&self, other: &UpgradeStatus) -> bool
fn eq(&self, other: &UpgradeStatus) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpgradeStatus