#[non_exhaustive]pub struct UtilizationReport {
pub name: String,
pub display_name: String,
pub state: State,
pub state_time: Option<Timestamp>,
pub error: Option<Status>,
pub create_time: Option<Timestamp>,
pub time_frame: TimeFrame,
pub frame_end_time: Option<Timestamp>,
pub vm_count: i32,
pub vms: Vec<VmUtilizationInfo>,
/* private fields */
}Expand description
Utilization report details the utilization (CPU, memory, etc.) of selected source VMs.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The report unique name.
display_name: StringThe report display name, as assigned by the user.
state: StateOutput only. Current state of the report.
state_time: Option<Timestamp>Output only. The time the state was last set.
error: Option<Status>Output only. Provides details on the state of the report in case of an error.
create_time: Option<Timestamp>Output only. The time the report was created (this refers to the time of the request, not the time the report creation completed).
time_frame: TimeFrameTime frame of the report.
frame_end_time: Option<Timestamp>Output only. The point in time when the time frame ends. Notice that the time frame is counted backwards. For instance if the “frame_end_time” value is 2021/01/20 and the time frame is WEEK then the report covers the week between 2021/01/20 and 2021/01/14.
vm_count: i32Output only. Total number of VMs included in the report.
vms: Vec<VmUtilizationInfo>List of utilization information per VM. When sent as part of the request, the “vm_id” field is used in order to specify which VMs to include in the report. In that case all other fields are ignored.
Implementations
Sourceimpl UtilizationReport
impl UtilizationReport
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Example
let x = UtilizationReport::new().set_display_name("example");Sourcepub fn set_state_time<T>(self, v: T) -> Self
pub fn set_state_time<T>(self, v: T) -> Self
Sets the value of state_time.
Example
use wkt::Timestamp;
let x = UtilizationReport::new().set_state_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_state_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_state_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of state_time.
Example
use wkt::Timestamp;
let x = UtilizationReport::new().set_or_clear_state_time(Some(Timestamp::default()/* use setters */));
let x = UtilizationReport::new().set_or_clear_state_time(None::<Timestamp>);Sourcepub fn set_or_clear_error<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_error<T>(self, v: Option<T>) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = UtilizationReport::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = UtilizationReport::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = UtilizationReport::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_time_frame<T: Into<TimeFrame>>(self, v: T) -> Self
pub fn set_time_frame<T: Into<TimeFrame>>(self, v: T) -> Self
Sets the value of time_frame.
Example
use google_cloud_vmmigration_v1::model::utilization_report::TimeFrame;
let x0 = UtilizationReport::new().set_time_frame(TimeFrame::Week);
let x1 = UtilizationReport::new().set_time_frame(TimeFrame::Month);
let x2 = UtilizationReport::new().set_time_frame(TimeFrame::Year);Sourcepub fn set_frame_end_time<T>(self, v: T) -> Self
pub fn set_frame_end_time<T>(self, v: T) -> Self
Sets the value of frame_end_time.
Example
use wkt::Timestamp;
let x = UtilizationReport::new().set_frame_end_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_frame_end_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_frame_end_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of frame_end_time.
Example
use wkt::Timestamp;
let x = UtilizationReport::new().set_or_clear_frame_end_time(Some(Timestamp::default()/* use setters */));
let x = UtilizationReport::new().set_or_clear_frame_end_time(None::<Timestamp>);Sourcepub fn set_vm_count<T: Into<i32>>(self, v: T) -> Self
pub fn set_vm_count<T: Into<i32>>(self, v: T) -> Self