#[non_exhaustive]pub struct VmwareSourceDetails {
pub username: String,
pub password: String,
pub vcenter_ip: String,
pub thumbprint: String,
pub resolved_vcenter_host: String,
/* private fields */
}Expand description
VmwareSourceDetails message describes a specific source details for the vmware source type.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.username: StringThe credentials username.
password: StringInput only. The credentials password. This is write only and can not be read in a GET operation.
vcenter_ip: StringThe ip address of the vcenter this Source represents.
thumbprint: StringThe thumbprint representing the certificate for the vcenter.
resolved_vcenter_host: StringThe hostname of the vcenter.
Implementations
Sourceimpl VmwareSourceDetails
impl VmwareSourceDetails
Sourcepub fn set_username<T: Into<String>>(self, v: T) -> Self
pub fn set_username<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_password<T: Into<String>>(self, v: T) -> Self
pub fn set_password<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_vcenter_ip<T: Into<String>>(self, v: T) -> Self
pub fn set_vcenter_ip<T: Into<String>>(self, v: T) -> Self
Sets the value of vcenter_ip.
Example
ⓘ
let x = VmwareSourceDetails::new().set_vcenter_ip("example");Sourcepub fn set_thumbprint<T: Into<String>>(self, v: T) -> Self
pub fn set_thumbprint<T: Into<String>>(self, v: T) -> Self
Sets the value of thumbprint.
Example
ⓘ
let x = VmwareSourceDetails::new().set_thumbprint("example");Sourcepub fn set_resolved_vcenter_host<T: Into<String>>(self, v: T) -> Self
pub fn set_resolved_vcenter_host<T: Into<String>>(self, v: T) -> Self
Sets the value of resolved_vcenter_host.
Example
ⓘ
let x = VmwareSourceDetails::new().set_resolved_vcenter_host("example");Trait Implementations
Sourceimpl Clone for VmwareSourceDetails
impl Clone for VmwareSourceDetails
Sourcefn clone(&self) -> VmwareSourceDetails
fn clone(&self) -> VmwareSourceDetails
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VmwareSourceDetails
impl Debug for VmwareSourceDetails
Sourceimpl Default for VmwareSourceDetails
impl Default for VmwareSourceDetails
Sourcefn default() -> VmwareSourceDetails
fn default() -> VmwareSourceDetails
Returns the “default value” for a type. Read more
Sourceimpl Message for VmwareSourceDetails
impl Message for VmwareSourceDetails
Sourceimpl PartialEq for VmwareSourceDetails
impl PartialEq for VmwareSourceDetails
Sourcefn eq(&self, other: &VmwareSourceDetails) -> bool
fn eq(&self, other: &VmwareSourceDetails) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for VmwareSourceDetails