#[non_exhaustive]pub struct AzureSourceDetails {
pub subscription_id: String,
pub azure_location: String,
pub state: State,
pub error: Option<Status>,
pub migration_resources_user_tags: HashMap<String, String>,
pub resource_group_id: String,
pub credentials_type: Option<CredentialsType>,
/* private fields */
}Expand description
AzureSourceDetails message describes a specific source details for the Azure source type.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.subscription_id: StringImmutable. Azure subscription ID.
azure_location: StringImmutable. The Azure location (region) that the source VMs will be migrated from.
state: StateOutput only. State of the source as determined by the health check.
error: Option<Status>Output only. Provides details on the state of the Source in case of an error.
User specified tags to add to every M2VM generated resource in Azure.
These tags will be set in addition to the default tags that are set as part
of the migration process. The tags must not begin with the reserved prefix
m4ce or m2vm.
resource_group_id: StringOutput only. The ID of the Azure resource group that contains all resources related to the migration process of this source.
credentials_type: Option<CredentialsType>Implementations
Sourceimpl AzureSourceDetails
impl AzureSourceDetails
Sourcepub fn set_subscription_id<T: Into<String>>(self, v: T) -> Self
pub fn set_subscription_id<T: Into<String>>(self, v: T) -> Self
Sets the value of subscription_id.
Example
let x = AzureSourceDetails::new().set_subscription_id("example");Sourcepub fn set_azure_location<T: Into<String>>(self, v: T) -> Self
pub fn set_azure_location<T: Into<String>>(self, v: T) -> Self
Sets the value of azure_location.
Example
let x = AzureSourceDetails::new().set_azure_location("example");Sourcepub fn set_or_clear_error<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_error<T>(self, v: Option<T>) -> Self
Sets the value of migration_resources_user_tags.
Example
let x = AzureSourceDetails::new().set_migration_resources_user_tags([
("key0", "abc"),
("key1", "xyz"),
]);Sourcepub fn set_resource_group_id<T: Into<String>>(self, v: T) -> Self
pub fn set_resource_group_id<T: Into<String>>(self, v: T) -> Self
Sets the value of resource_group_id.
Example
let x = AzureSourceDetails::new().set_resource_group_id("example");Sourcepub fn set_credentials_type<T: Into<Option<CredentialsType>>>(
self,
v: T,
) -> Self
pub fn set_credentials_type<T: Into<Option<CredentialsType>>>( self, v: T, ) -> Self
Sets the value of credentials_type.
Note that all the setters affecting credentials_type are mutually
exclusive.
Example
use google_cloud_vmmigration_v1::model::azure_source_details::ClientSecretCredentials;
let x = AzureSourceDetails::new().set_credentials_type(Some(
google_cloud_vmmigration_v1::model::azure_source_details::CredentialsType::ClientSecretCreds(ClientSecretCredentials::default().into())));Sourcepub fn client_secret_creds(&self) -> Option<&Box<ClientSecretCredentials>>
pub fn client_secret_creds(&self) -> Option<&Box<ClientSecretCredentials>>
The value of credentials_type
if it holds a ClientSecretCreds, None if the field is not set or
holds a different branch.
Sourcepub fn set_client_secret_creds<T: Into<Box<ClientSecretCredentials>>>(
self,
v: T,
) -> Self
pub fn set_client_secret_creds<T: Into<Box<ClientSecretCredentials>>>( self, v: T, ) -> Self
Sets the value of credentials_type
to hold a ClientSecretCreds.
Note that all the setters affecting credentials_type are
mutually exclusive.
Example
use google_cloud_vmmigration_v1::model::azure_source_details::ClientSecretCredentials;
let x = AzureSourceDetails::new().set_client_secret_creds(ClientSecretCredentials::default()/* use setters */);
assert!(x.client_secret_creds().is_some());Trait Implementations
Sourceimpl Clone for AzureSourceDetails
impl Clone for AzureSourceDetails
Sourcefn clone(&self) -> AzureSourceDetails
fn clone(&self) -> AzureSourceDetails
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for AzureSourceDetails
impl Debug for AzureSourceDetails
Sourceimpl Default for AzureSourceDetails
impl Default for AzureSourceDetails
Sourcefn default() -> AzureSourceDetails
fn default() -> AzureSourceDetails
Sourceimpl Message for AzureSourceDetails
impl Message for AzureSourceDetails
Sourceimpl PartialEq for AzureSourceDetails
impl PartialEq for AzureSourceDetails
Sourcefn eq(&self, other: &AzureSourceDetails) -> bool
fn eq(&self, other: &AzureSourceDetails) -> bool
self and other values to be equal, and is used by ==.