#[non_exhaustive]pub struct CutoverJob {
pub create_time: Option<Timestamp>,
pub end_time: Option<Timestamp>,
pub name: String,
pub state: State,
pub state_time: Option<Timestamp>,
pub progress_percent: i32,
pub error: Option<Status>,
pub state_message: String,
pub steps: Vec<CutoverStep>,
pub target_vm_details: Option<TargetVmDetails>,
/* private fields */
}Expand description
CutoverJob message describes a cutover of a migrating VM. The CutoverJob is the operation of shutting down the VM, creating a snapshot and cloning the VM using the replicated snapshot.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.create_time: Option<Timestamp>Output only. The time the cutover job was created (as an API call, not when it was actually created in the target).
end_time: Option<Timestamp>Output only. The time the cutover job had finished.
name: StringOutput only. The name of the cutover job.
state: StateOutput only. State of the cutover job.
state_time: Option<Timestamp>Output only. The time the state was last updated.
progress_percent: i32Output only. The current progress in percentage of the cutover job.
error: Option<Status>Output only. Provides details for the errors that led to the Cutover Job’s state.
state_message: StringOutput only. A message providing possible extra details about the current state.
steps: Vec<CutoverStep>Output only. The cutover steps list representing its progress.
target_vm_details: Option<TargetVmDetails>Details of the VM to create as the target of this cutover job.
Implementations
Sourceimpl CutoverJob
impl CutoverJob
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = CutoverJob::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = CutoverJob::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = CutoverJob::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_end_time<T>(self, v: T) -> Self
pub fn set_end_time<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
Sourcepub fn set_state_time<T>(self, v: T) -> Self
pub fn set_state_time<T>(self, v: T) -> Self
Sets the value of state_time.
Example
use wkt::Timestamp;
let x = CutoverJob::new().set_state_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_state_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_state_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of state_time.
Example
use wkt::Timestamp;
let x = CutoverJob::new().set_or_clear_state_time(Some(Timestamp::default()/* use setters */));
let x = CutoverJob::new().set_or_clear_state_time(None::<Timestamp>);Sourcepub fn set_progress_percent<T: Into<i32>>(self, v: T) -> Self
pub fn set_progress_percent<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_or_clear_error<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_error<T>(self, v: Option<T>) -> Self
Sourcepub fn set_state_message<T: Into<String>>(self, v: T) -> Self
pub fn set_state_message<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_target_vm_details<T: Into<Option<TargetVmDetails>>>(
self,
v: T,
) -> Self
pub fn set_target_vm_details<T: Into<Option<TargetVmDetails>>>( self, v: T, ) -> Self
Sets the value of target_vm_details.
Note that all the setters affecting target_vm_details are mutually
exclusive.
Example
use google_cloud_vmmigration_v1::model::ComputeEngineTargetDetails;
let x = CutoverJob::new().set_target_vm_details(Some(
google_cloud_vmmigration_v1::model::cutover_job::TargetVmDetails::ComputeEngineTargetDetails(ComputeEngineTargetDetails::default().into())));Sourcepub fn compute_engine_target_details(
&self,
) -> Option<&Box<ComputeEngineTargetDetails>>
pub fn compute_engine_target_details( &self, ) -> Option<&Box<ComputeEngineTargetDetails>>
The value of target_vm_details
if it holds a ComputeEngineTargetDetails, None if the field is not set or
holds a different branch.
Sourcepub fn set_compute_engine_target_details<T: Into<Box<ComputeEngineTargetDetails>>>(
self,
v: T,
) -> Self
pub fn set_compute_engine_target_details<T: Into<Box<ComputeEngineTargetDetails>>>( self, v: T, ) -> Self
Sets the value of target_vm_details
to hold a ComputeEngineTargetDetails.
Note that all the setters affecting target_vm_details are
mutually exclusive.
Example
use google_cloud_vmmigration_v1::model::ComputeEngineTargetDetails;
let x = CutoverJob::new().set_compute_engine_target_details(ComputeEngineTargetDetails::default()/* use setters */);
assert!(x.compute_engine_target_details().is_some());
assert!(x.compute_engine_disks_target_details().is_none());Sourcepub fn compute_engine_disks_target_details(
&self,
) -> Option<&Box<ComputeEngineDisksTargetDetails>>
pub fn compute_engine_disks_target_details( &self, ) -> Option<&Box<ComputeEngineDisksTargetDetails>>
The value of target_vm_details
if it holds a ComputeEngineDisksTargetDetails, None if the field is not set or
holds a different branch.
Sourcepub fn set_compute_engine_disks_target_details<T: Into<Box<ComputeEngineDisksTargetDetails>>>(
self,
v: T,
) -> Self
pub fn set_compute_engine_disks_target_details<T: Into<Box<ComputeEngineDisksTargetDetails>>>( self, v: T, ) -> Self
Sets the value of target_vm_details
to hold a ComputeEngineDisksTargetDetails.
Note that all the setters affecting target_vm_details are
mutually exclusive.
Example
use google_cloud_vmmigration_v1::model::ComputeEngineDisksTargetDetails;
let x = CutoverJob::new().set_compute_engine_disks_target_details(ComputeEngineDisksTargetDetails::default()/* use setters */);
assert!(x.compute_engine_disks_target_details().is_some());
assert!(x.compute_engine_target_details().is_none());Trait Implementations
Sourceimpl Clone for CutoverJob
impl Clone for CutoverJob
Sourcefn clone(&self) -> CutoverJob
fn clone(&self) -> CutoverJob
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CutoverJob
impl Debug for CutoverJob
Sourceimpl Default for CutoverJob
impl Default for CutoverJob
Sourcefn default() -> CutoverJob
fn default() -> CutoverJob
Sourceimpl PartialEq for CutoverJob
impl PartialEq for CutoverJob
Sourcefn eq(&self, other: &CutoverJob) -> bool
fn eq(&self, other: &CutoverJob) -> bool
self and other values to be equal, and is used by ==.