#[non_exhaustive]pub struct DataDiskImageImport {
pub guest_os_features: Vec<String>,
/* private fields */
}Expand description
Used when the image import is not using OS adaptation process.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.guest_os_features: Vec<String>Optional. A list of guest OS features to apply to the imported image. These features are flags that are used by Compute Engine to enable certain capabilities for virtual machine instances that are created from the image.
This field does not change the OS of the image; it only marks the image with the specified features. The user must ensure that the OS is compatible with the features.
For a list of available features, see https://cloud.google.com/compute/docs/images/create-custom#guest-os-features.
Implementations
Sourceimpl DataDiskImageImport
impl DataDiskImageImport
Sourcepub fn set_guest_os_features<T, V>(self, v: T) -> Self
pub fn set_guest_os_features<T, V>(self, v: T) -> Self
Sets the value of guest_os_features.
Example
ⓘ
let x = DataDiskImageImport::new().set_guest_os_features(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for DataDiskImageImport
impl Clone for DataDiskImageImport
Sourcefn clone(&self) -> DataDiskImageImport
fn clone(&self) -> DataDiskImageImport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DataDiskImageImport
impl Debug for DataDiskImageImport
Sourceimpl Default for DataDiskImageImport
impl Default for DataDiskImageImport
Sourcefn default() -> DataDiskImageImport
fn default() -> DataDiskImageImport
Returns the “default value” for a type. Read more
Sourceimpl Message for DataDiskImageImport
impl Message for DataDiskImageImport
Sourceimpl PartialEq for DataDiskImageImport
impl PartialEq for DataDiskImageImport
Sourcefn eq(&self, other: &DataDiskImageImport) -> bool
fn eq(&self, other: &DataDiskImageImport) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DataDiskImageImport