#[non_exhaustive]pub struct DatacenterConnector {Show 14 fields
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub name: String,
pub registration_id: String,
pub service_account: String,
pub version: String,
pub bucket: String,
pub state: State,
pub state_time: Option<Timestamp>,
pub error: Option<Status>,
pub appliance_infrastructure_version: String,
pub appliance_software_version: String,
pub available_versions: Option<AvailableUpdates>,
pub upgrade_status: Option<UpgradeStatus>,
/* private fields */
}Expand description
DatacenterConnector message describes a connector between the Source and Google Cloud, which is installed on a vmware datacenter (an OVA vm installed by the user) to connect the Datacenter to Google Cloud and support vm migration data transfer.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.create_time: Option<Timestamp>Output only. The time the connector was created (as an API call, not when it was actually installed).
update_time: Option<Timestamp>Output only. The last time the connector was updated with an API call.
name: StringOutput only. The connector’s name.
registration_id: StringImmutable. A unique key for this connector. This key is internal to the OVA connector and is supplied with its creation during the registration process and can not be modified.
service_account: StringThe service account to use in the connector when communicating with the cloud.
version: StringThe version running in the DatacenterConnector. This is supplied by the OVA connector during the registration process and can not be modified.
bucket: StringOutput only. The communication channel between the datacenter connector and Google Cloud.
state: StateOutput only. State of the DatacenterConnector, as determined by the health checks.
state_time: Option<Timestamp>Output only. The time the state was last set.
error: Option<Status>Output only. Provides details on the state of the Datacenter Connector in case of an error.
appliance_infrastructure_version: StringOutput only. Appliance OVA version. This is the OVA which is manually installed by the user and contains the infrastructure for the automatically updatable components on the appliance.
appliance_software_version: StringOutput only. Appliance last installed update bundle version. This is the version of the automatically updatable components on the appliance.
available_versions: Option<AvailableUpdates>Output only. The available versions for updating this appliance.
upgrade_status: Option<UpgradeStatus>Output only. The status of the current / last upgradeAppliance operation.
Implementations
Sourceimpl DatacenterConnector
impl DatacenterConnector
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = DatacenterConnector::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = DatacenterConnector::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = DatacenterConnector::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = DatacenterConnector::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = DatacenterConnector::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = DatacenterConnector::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_registration_id<T: Into<String>>(self, v: T) -> Self
pub fn set_registration_id<T: Into<String>>(self, v: T) -> Self
Sets the value of registration_id.
Example
let x = DatacenterConnector::new().set_registration_id("example");Sourcepub fn set_service_account<T: Into<String>>(self, v: T) -> Self
pub fn set_service_account<T: Into<String>>(self, v: T) -> Self
Sets the value of service_account.
Example
let x = DatacenterConnector::new().set_service_account("example");Sourcepub fn set_version<T: Into<String>>(self, v: T) -> Self
pub fn set_version<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_bucket<T: Into<String>>(self, v: T) -> Self
pub fn set_bucket<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_state_time<T>(self, v: T) -> Self
pub fn set_state_time<T>(self, v: T) -> Self
Sets the value of state_time.
Example
use wkt::Timestamp;
let x = DatacenterConnector::new().set_state_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_state_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_state_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of state_time.
Example
use wkt::Timestamp;
let x = DatacenterConnector::new().set_or_clear_state_time(Some(Timestamp::default()/* use setters */));
let x = DatacenterConnector::new().set_or_clear_state_time(None::<Timestamp>);Sourcepub fn set_or_clear_error<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_error<T>(self, v: Option<T>) -> Self
Sourcepub fn set_appliance_infrastructure_version<T: Into<String>>(self, v: T) -> Self
pub fn set_appliance_infrastructure_version<T: Into<String>>(self, v: T) -> Self
Sets the value of appliance_infrastructure_version.
Example
let x = DatacenterConnector::new().set_appliance_infrastructure_version("example");Sourcepub fn set_appliance_software_version<T: Into<String>>(self, v: T) -> Self
pub fn set_appliance_software_version<T: Into<String>>(self, v: T) -> Self
Sets the value of appliance_software_version.
Example
let x = DatacenterConnector::new().set_appliance_software_version("example");Sourcepub fn set_available_versions<T>(self, v: T) -> Selfwhere
T: Into<AvailableUpdates>,
pub fn set_available_versions<T>(self, v: T) -> Selfwhere
T: Into<AvailableUpdates>,
Sets the value of available_versions.
Example
use google_cloud_vmmigration_v1::model::AvailableUpdates;
let x = DatacenterConnector::new().set_available_versions(AvailableUpdates::default()/* use setters */);Sourcepub fn set_or_clear_available_versions<T>(self, v: Option<T>) -> Selfwhere
T: Into<AvailableUpdates>,
pub fn set_or_clear_available_versions<T>(self, v: Option<T>) -> Selfwhere
T: Into<AvailableUpdates>,
Sets or clears the value of available_versions.
Example
use google_cloud_vmmigration_v1::model::AvailableUpdates;
let x = DatacenterConnector::new().set_or_clear_available_versions(Some(AvailableUpdates::default()/* use setters */));
let x = DatacenterConnector::new().set_or_clear_available_versions(None::<AvailableUpdates>);Sourcepub fn set_upgrade_status<T>(self, v: T) -> Selfwhere
T: Into<UpgradeStatus>,
pub fn set_upgrade_status<T>(self, v: T) -> Selfwhere
T: Into<UpgradeStatus>,
Sets the value of upgrade_status.
Example
use google_cloud_vmmigration_v1::model::UpgradeStatus;
let x = DatacenterConnector::new().set_upgrade_status(UpgradeStatus::default()/* use setters */);Sourcepub fn set_or_clear_upgrade_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<UpgradeStatus>,
pub fn set_or_clear_upgrade_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<UpgradeStatus>,
Sets or clears the value of upgrade_status.
Example
use google_cloud_vmmigration_v1::model::UpgradeStatus;
let x = DatacenterConnector::new().set_or_clear_upgrade_status(Some(UpgradeStatus::default()/* use setters */));
let x = DatacenterConnector::new().set_or_clear_upgrade_status(None::<UpgradeStatus>);Trait Implementations
Sourceimpl Clone for DatacenterConnector
impl Clone for DatacenterConnector
Sourcefn clone(&self) -> DatacenterConnector
fn clone(&self) -> DatacenterConnector
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DatacenterConnector
impl Debug for DatacenterConnector
Sourceimpl Default for DatacenterConnector
impl Default for DatacenterConnector
Sourcefn default() -> DatacenterConnector
fn default() -> DatacenterConnector
Sourceimpl Message for DatacenterConnector
impl Message for DatacenterConnector
Sourceimpl PartialEq for DatacenterConnector
impl PartialEq for DatacenterConnector
Sourcefn eq(&self, other: &DatacenterConnector) -> bool
fn eq(&self, other: &DatacenterConnector) -> bool
self and other values to be equal, and is used by ==.