#[non_exhaustive]pub struct DiskMigrationJob {
pub name: String,
pub target_details: Option<DiskMigrationJobTargetDetails>,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub state: State,
pub errors: Vec<Status>,
pub steps: Vec<DiskMigrationStep>,
pub source_disk_details: Option<SourceDiskDetails>,
/* private fields */
}Expand description
Describes the disk which will be migrated from the source environment. The source disk has to be unattached.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. Identifier. The identifier of the DiskMigrationJob.
target_details: Option<DiskMigrationJobTargetDetails>Required. Details of the target Disk in Compute Engine.
create_time: Option<Timestamp>Output only. The time the DiskMigrationJob resource was created.
update_time: Option<Timestamp>Output only. The last time the DiskMigrationJob resource was updated.
state: StateOutput only. State of the DiskMigrationJob.
errors: Vec<Status>Output only. Provides details on the errors that led to the disk migration job’s state in case of an error.
steps: Vec<DiskMigrationStep>Output only. The disk migration steps list representing its progress.
source_disk_details: Option<SourceDiskDetails>Unattached source disk details.
Implementations
Sourceimpl DiskMigrationJob
impl DiskMigrationJob
Sourcepub fn set_target_details<T>(self, v: T) -> Selfwhere
T: Into<DiskMigrationJobTargetDetails>,
pub fn set_target_details<T>(self, v: T) -> Selfwhere
T: Into<DiskMigrationJobTargetDetails>,
Sets the value of target_details.
Example
use google_cloud_vmmigration_v1::model::DiskMigrationJobTargetDetails;
let x = DiskMigrationJob::new().set_target_details(DiskMigrationJobTargetDetails::default()/* use setters */);Sourcepub fn set_or_clear_target_details<T>(self, v: Option<T>) -> Selfwhere
T: Into<DiskMigrationJobTargetDetails>,
pub fn set_or_clear_target_details<T>(self, v: Option<T>) -> Selfwhere
T: Into<DiskMigrationJobTargetDetails>,
Sets or clears the value of target_details.
Example
use google_cloud_vmmigration_v1::model::DiskMigrationJobTargetDetails;
let x = DiskMigrationJob::new().set_or_clear_target_details(Some(DiskMigrationJobTargetDetails::default()/* use setters */));
let x = DiskMigrationJob::new().set_or_clear_target_details(None::<DiskMigrationJobTargetDetails>);Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = DiskMigrationJob::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = DiskMigrationJob::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = DiskMigrationJob::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = DiskMigrationJob::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = DiskMigrationJob::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = DiskMigrationJob::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_errors<T, V>(self, v: T) -> Self
pub fn set_errors<T, V>(self, v: T) -> Self
Sourcepub fn set_source_disk_details<T: Into<Option<SourceDiskDetails>>>(
self,
v: T,
) -> Self
pub fn set_source_disk_details<T: Into<Option<SourceDiskDetails>>>( self, v: T, ) -> Self
Sets the value of source_disk_details.
Note that all the setters affecting source_disk_details are mutually
exclusive.
Example
use google_cloud_vmmigration_v1::model::AwsSourceDiskDetails;
let x = DiskMigrationJob::new().set_source_disk_details(Some(
google_cloud_vmmigration_v1::model::disk_migration_job::SourceDiskDetails::AwsSourceDiskDetails(AwsSourceDiskDetails::default().into())));Sourcepub fn aws_source_disk_details(&self) -> Option<&Box<AwsSourceDiskDetails>>
pub fn aws_source_disk_details(&self) -> Option<&Box<AwsSourceDiskDetails>>
The value of source_disk_details
if it holds a AwsSourceDiskDetails, None if the field is not set or
holds a different branch.
Sourcepub fn set_aws_source_disk_details<T: Into<Box<AwsSourceDiskDetails>>>(
self,
v: T,
) -> Self
pub fn set_aws_source_disk_details<T: Into<Box<AwsSourceDiskDetails>>>( self, v: T, ) -> Self
Sets the value of source_disk_details
to hold a AwsSourceDiskDetails.
Note that all the setters affecting source_disk_details are
mutually exclusive.
Example
use google_cloud_vmmigration_v1::model::AwsSourceDiskDetails;
let x = DiskMigrationJob::new().set_aws_source_disk_details(AwsSourceDiskDetails::default()/* use setters */);
assert!(x.aws_source_disk_details().is_some());Trait Implementations
Sourceimpl Clone for DiskMigrationJob
impl Clone for DiskMigrationJob
Sourcefn clone(&self) -> DiskMigrationJob
fn clone(&self) -> DiskMigrationJob
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DiskMigrationJob
impl Debug for DiskMigrationJob
Sourceimpl Default for DiskMigrationJob
impl Default for DiskMigrationJob
Sourcefn default() -> DiskMigrationJob
fn default() -> DiskMigrationJob
Sourceimpl Message for DiskMigrationJob
impl Message for DiskMigrationJob
Sourceimpl PartialEq for DiskMigrationJob
impl PartialEq for DiskMigrationJob
Sourcefn eq(&self, other: &DiskMigrationJob) -> bool
fn eq(&self, other: &DiskMigrationJob) -> bool
self and other values to be equal, and is used by ==.