#[non_exhaustive]pub struct ImageImportOsAdaptationParameters {
pub generalize: bool,
pub license_type: ComputeEngineLicenseType,
pub boot_conversion: BootConversion,
pub adaptation_modifiers: Vec<AdaptationModifier>,
/* private fields */
}Expand description
Parameters affecting the OS adaptation process.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.generalize: boolOptional. Set to true in order to generalize the imported image. The generalization process enables co-existence of multiple VMs created from the same image. For Windows, generalizing the image removes computer-specific information such as installed drivers and the computer security identifier (SID).
license_type: ComputeEngineLicenseTypeOptional. Choose which type of license to apply to the imported image.
boot_conversion: BootConversionOptional. By default the image will keep its existing boot option. Setting this property will trigger an internal process which will convert the image from using the existing boot option to another. The size of the boot disk might be increased to allow the conversion
adaptation_modifiers: Vec<AdaptationModifier>Optional. Modifiers to be used as configuration of the OS adaptation process.
Implementations
Sourceimpl ImageImportOsAdaptationParameters
impl ImageImportOsAdaptationParameters
Sourcepub fn set_generalize<T: Into<bool>>(self, v: T) -> Self
pub fn set_generalize<T: Into<bool>>(self, v: T) -> Self
Sets the value of generalize.
Example
let x = ImageImportOsAdaptationParameters::new().set_generalize(true);Sourcepub fn set_license_type<T: Into<ComputeEngineLicenseType>>(self, v: T) -> Self
pub fn set_license_type<T: Into<ComputeEngineLicenseType>>(self, v: T) -> Self
Sets the value of license_type.
Example
use google_cloud_vmmigration_v1::model::ComputeEngineLicenseType;
let x0 = ImageImportOsAdaptationParameters::new().set_license_type(ComputeEngineLicenseType::Payg);
let x1 = ImageImportOsAdaptationParameters::new().set_license_type(ComputeEngineLicenseType::Byol);Sourcepub fn set_boot_conversion<T: Into<BootConversion>>(self, v: T) -> Self
pub fn set_boot_conversion<T: Into<BootConversion>>(self, v: T) -> Self
Sets the value of boot_conversion.
Example
use google_cloud_vmmigration_v1::model::BootConversion;
let x0 = ImageImportOsAdaptationParameters::new().set_boot_conversion(BootConversion::None);
let x1 = ImageImportOsAdaptationParameters::new().set_boot_conversion(BootConversion::BiosToEfi);Sourcepub fn set_adaptation_modifiers<T, V>(self, v: T) -> Self
pub fn set_adaptation_modifiers<T, V>(self, v: T) -> Self
Sets the value of adaptation_modifiers.
Example
use google_cloud_vmmigration_v1::model::AdaptationModifier;
let x = ImageImportOsAdaptationParameters::new()
.set_adaptation_modifiers([
AdaptationModifier::default()/* use setters */,
AdaptationModifier::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for ImageImportOsAdaptationParameters
impl Clone for ImageImportOsAdaptationParameters
Sourcefn clone(&self) -> ImageImportOsAdaptationParameters
fn clone(&self) -> ImageImportOsAdaptationParameters
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for ImageImportOsAdaptationParameters
impl Default for ImageImportOsAdaptationParameters
Sourcefn default() -> ImageImportOsAdaptationParameters
fn default() -> ImageImportOsAdaptationParameters
Sourceimpl PartialEq for ImageImportOsAdaptationParameters
impl PartialEq for ImageImportOsAdaptationParameters
Sourcefn eq(&self, other: &ImageImportOsAdaptationParameters) -> bool
fn eq(&self, other: &ImageImportOsAdaptationParameters) -> bool
self and other values to be equal, and is used by ==.